///////////////////////////////////////////////////////////////////////////////
//                                                                             
//	$Revision: 29 $																
//																				
//	Name       : SwiApiCm.h														
//                                                                             
//	Purpose    : SWI common SDK API (across all technologies)					
//					                                                            
//	Copyright (c) 2003 Sierra Wireless, Inc.  All rights reserved			    
//                                                                             
///////////////////////////////////////////////////////////////////////////////
#ifndef __SWIAPI_CM
#define __SWIAPI_CM

#ifndef SWI_API
#define SWI_API __declspec(dllimport)
#endif

#ifdef __cplusplus
extern "C" {
#endif

#include "SwiRcodes.h"
#include "SwiStructsCm.h"

///////////////////////////////////////////////////////////////////////////////
//                                                                             
//						SWI Common API functions
//                                                                             
//  All API functions return ::SWI_RCODE enum type value. For particular error 
//  code see SwiRcodes.h.                                                      
//																			
//  For details about parameter types, enumeration values and structures       
//  see the corresponding structure files.                                     
//                                                                             
///////////////////////////////////////////////////////////////////////////////

/** 
 * \defgroup GroupApiMgmt API Management and Device Selection 
 */
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
///	This function is used to initialize the API sub-system.
///
/// This function must be called first before any other function calls 
///	are made.
///		
///	After calling this function, ::SwiGetAvailAirServers can be called to
///	retrieve a list	of air servers.  ::SwiSelectAirServer must be used to commit
/// to a specific air server before calling any modem control and status API 
/// functions.
///
///	::SwiApiStartup/::SwiApiShutdown does not have to be called when device
///	insertion/removal is detected.  Simply use ::SwiSelectAirServer to 
///	bind to a newly inserted device.
///
///	SwiApiShutdown must be called to terminate usage of the API and release
///	any resources allocated by the ::SwiApiStartup function call.  
///
///	This function applies to all devices.
///
///	\param	[IN] pOpenParams:	
///			Pointer to a SWI_STRUCT_ApiStartup structure which defines
///			customizations to initialize the API
///
///	\return	::SWI_RCODE_OK:			
///			API initialized successfully
///
///	\return	::SWI_RCODE_FAILED:		
///			The API sub-system was not initialized successfully.
///
///	\return	::SWI_RCODE_SYSTEM_ERROR: 
///			The API failed to initialize due to limited system resources when
///			the API requested memory from the OS.
///
///	\return	See ::SWI_RCODE for other error return codes
///
/// \return If an error is returned or to re-initialize the API, 
//			::SwiApiShutdown must be called before calling this function again.
///
///	\sa SwiApiShutdown
///	\sa SWI_STRUCT_ApiStartup
///	\sa See sample code, ConnectApi
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiApiStartup(SWI_STRUCT_ApiStartup *pOpenParams);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is called to shut down the API sub-system.  Control and 
/// status information will no longer be available after making this call.  
/// Existing internet data connections will not be affected by this call.
///
/// You must re-initialize the API using ::SwiApiStartup before any further API 
/// functions can be called.  
///
/// \return ::SWI_RCODE_OK:
///			API closed successfully
///
/// \return See ::SWI_RCODE for additional information.
///
/// \sa SwiApiStartup
///	\sa See sample code, ConnectApi
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiApiShutdown();

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve a list of available air servers.
///
/// Air servers are deemed available if the appropriate driver interface, is
/// found.  These interfaces must be capable of supporting a control and status
/// command path to the air server.  ::SwiSelectAirServer must be called to 
/// bind to the air server before any command and status functions are called.
///
/// Air servers locked for exclusive use by an application are also included.
///
///	\param	[IN] sList:	
///			A structure of type SWI_STRUCT_AirServerList which contains a
///			list of available air servers.
///
/// \return	::SWI_RCODE_OK:		
///			List of available servers is successfully retrieved.
///
///	\return ::SWI_RCODE_FAILED:	
///			Failed to retrieve the list of available air servers.
///
/// \sa SWI_STRUCT_AirServerList
/// \sa SwiSelectAirServer
/// \sa See sample code, ConnectApi
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetAvailAirServers(SWI_STRUCT_AirServerList &sList);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to bind the API to a specific air server.
///
/// Use ::SwiGetAvailAirServers to retrieve a list of available air servers.
/// Modem control and status API calls can not be invoked until this call is
/// completed.  The API can only bind to one air server at a time.  
///
/// If the API is already bound to an air server, calling this function will 
/// cancel all pending requests and re-bind to the new air server.  
///
///	\param	[IN] airServer:	
///			Air server you are connecting to. 
///			This tells the API what services are supported.
///
/// \return ::SWI_RCODE_OK:
///			API successfully bound to air server
///
///	\return	::SWI_RCODE_FAILED:
///			API failed to bind to new air server.  
///
/// \return	See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_STRUCT_AirServer
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSelectAirServer(SWI_STRUCT_AirServer &airServer);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve additional information about a
///	particular air server.
///
/// See SWI_STRUCT_AirServerExtended for list of additional information that 
/// can be retrieved.
///
///	\param	[IN] sAirServer:	
///			A structure of type SWI_STRUCT_AirServer which specifies the
///			the air server of interest.
///
/// \param	[OUT]sInfo:			
///			A structure of type SWI_STRUCT_AirServerExtended which contains
///			additional information about the requested air server.
///
/// \return	::SWI_RCODE_OK: 
///			Additional information successfully retrieved.
///
///	\return See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_STRUCT_AirServer
/// \sa SWI_STRUCT_AirServerExtended
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetAirServerInfo(SWI_STRUCT_AirServer sAirServer, 
									  SWI_STRUCT_AirServerExtended &sInfo);

/*@}*/ // End of API Management group

/**
 * \defgroup GroupNotif Notifications
 */
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// This function registers a callback handler to receive event notifications.		
///
/// This function can be called immediately after SwiApiStartup to ensure
/// the client application receives critical events.  
/// 
/// The following notifications are enabled by default and can not be disabled:
///
///		- ::SWI_NOTIFY_AirServerChange
///		- ::SWI_NOTIFY_LockAirServer
///		- ::SWIHW_NOTIFY_Power
///		- ::SWI_NOTIFY_MUX_Shutdown
///		- ::SWI_NOTIFY_Reset	
///		
///	Callback functions must be (re)registered every time ::SwiSelectAirServer
///	is called.  This ensures that features of the newly bound air server will 
/// have access to all the callback pointers.
///
///	On termination, ::SwiDeRegisterCallback should be called for each callback
/// function previously registered.
///				
///	All other notifications are disabled by default and must be enabled.
///
/// \param	[OUT] pCallback: 
///			Callback function pointer of type ::SWI_CALLBACK_EX to be registered
///			for incoming notifications.
///
/// \param	[IN]  nNotifications: 
///			Notification filter.  nNotifications should be set to 
///			0xFFFFFFFFFFFFFFFF to receive all possible notifications. 
///
/// \return See ::SWI_RCODE for additional information.
/// 
/// \sa SWI_CALLBACK_EX
/// \sa SwiDeRegisterCallback
/// \sa SwiApiStartup
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiRegisterCallback(SWI_CALLBACK_EX pCallback, 
									  U64 nNotifications);

///////////////////////////////////////////////////////////////////////////////
///
/// This function de-registers an application's callback handler.
///
/// After calling this function, notifications will no longer be passed to the
/// specified callback handler.
///
/// \param	[OUT] pCallback: 
///			Callback function pointer of type ::SWI_CALLBACK_EX to be
///			de-registered.
///
/// \return	::SWI_RCODE_OK: 
///			Callback function successfully de-registered.
///
///	\return ::SWI_RCODE_INVALID_PAR: 
///			An invalid parameter was passed
///
/// \return See ::SWI_RCODE for additional information.	
///
/// \sa SWI_CALLBACK_EX
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiDeRegisterCallback(SWI_CALLBACK_EX pCallback);

///////////////////////////////////////////////////////////////////////////////
///
/// This function turns the notification ON for the specified event.
///
/// Calling this function enables event notifications to be routed to the 
///	callback handler registered earlier using SwiRegisterCallback. If 
/// notifications are enabled when there is no registered callback function, 
///	the API will silently discard them as they arrive.  Similarly, if a filter
/// were defined, notifications will be silently discarded.
///
///	Modem resets disable notifications (but leave the callback function 
/// registered). You must explicitly re-enable notifications if a modem reset 
///	is detected (::SWI_NOTIFY_Reset).  
///
///	Once enabled, the modem will always send the current state of the 
/// notification object.  When that notification is generated will depend on
/// the object itself.  After the initial indication, notifications are only 
/// generated when there is a change in state.  Occasionally, notifications 
/// are generated at predefined intervals.  See a description of the 
/// notification object for more information.
///
///	The following notifications are enabled by default and can not be disabled:
///
///		- ::SWI_NOTIFY_AirServerChange
///		- ::SWI_NOTIFY_LockAirServer
///		- ::SWIHW_NOTIFY_Power
///		- ::SWI_NOTIFY_MUX_Shutdown
///		- ::SWI_NOTIFY_Reset		
///				
///	All other notifications are disabled by default and must be enabled.
///
/// Use SwiStopNotify to disable a notification event.
///
/// With GSM devices, multiple notifications can be enabled simultaneously
/// using ::SwiEnableNotif.
///			
/// \param	[IN] eNotify: 
///			SWI_TYPE_Notify notification to enable
///
///	\param	[IN] timeout: 
///			Response timeout value in milliseconds
///
/// \return ::SWI_RCODE_OK: 
///			Notification successfully enabled
///
///	\return See ::SWI_RCODE for additional information.
/// 
/// \sa SWI_TYPE_Notify
/// \sa SwiStopNotify
/// \sa SwiEnableNotif
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiNotify(SWI_TYPE_Notify eNotify, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function turns the notification OFF for the specified event.
///
/// After calling this function, the specified notifications will not be 
///	forwarded to the client's callback function.  ::SwiNotify must be used to
/// re-enable the notification.
///
///	The following notifications are enabled by default and can not be disabled:
///
///		- SWI_NOTIFY_AirServerChange
///		- SWI_NOTIFY_LockAirServer
///		- SWIHW_NOTIFY_Power
///		- SWI_NOTIFY_MUX_Shutdown
///		- SWI_NOTIFY_Reset
///
/// \param	[IN] eNotify: 
///			SWI_TYPE_Notify notification to disable
///
///	\param	[IN] timeout: 
///			Response timeout value in milliseconds
///
/// \return	See ::SWI_RCODE for additional information.	
/// 
/// \sa SWI_TYPE_Notify	
/// \sa SwiNotify
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiStopNotify(SWI_TYPE_Notify eNotify, U32 timeout);

/*@}*/ // End of Notification group

/** 
 * \defgroup GroupModemInfo Modem Information and Management
 */
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to get fundamental information from the modem.
/// 
/// The information returned is determined by setting the 
/// eDeviceInformationType field of sDeviceInformation_Request.  
/// 
///	\param	[IN] sDeviceInformation_Request:	
///			struct must be filled out to select type of information returned.
///
///	\param	[OUT] sDeviceInformation_Response:			
///			struct returned will contain the requested information.
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return	See ::SWI_RCODE for additional information.
///
/// \sa SWI_STRUCT_DeviceInformation_Request
/// \sa SWI_STRUCT_DeviceInformation_Response
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetDeviceInformation(const SWI_STRUCT_DeviceInformation_Request& sDeviceInformation_Request, 
										  SWI_STRUCT_DeviceInformation_Response& sDeviceInformation_Response,
										  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function returns the device's unique identity as a string. The 
/// returned value is the ESN (Electronic Serial Number) or EID 
///	(Electronic Identity) of the modem.
///
/// The ESN is in the form of an 14-character string of decimal numerals.  
/// The string is null terminated (adding a 15th byte to the length).  The 
/// content of the ESN includes several concatenated components, as specified
/// for GPRS.
///
/// \param	[OUT] szDeviceID: 
///			A string representing the Device ID (NULL terminated).
///
///	\param	[IN] sizeBuffer: 
///			Size of buffer provided for the device ID.  A buffer of 15 bytes
///			is recommended.
///
///	\param	[IN] timeout: 
///			Response timeout value in milliseconds
///
/// \return See ::SWI_RCODE for additional information.	
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetDeviceID(LPTSTR szDeviceID, 
								 U32 sizeBuffer, 
								 U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function returns the device's firmware version in a string.  
///
/// The firmware version string varies in length. It is recommended that a 
/// character string of 80 characters be allocated to store this return value.
///			
/// \param	[OUT] szFWVersion:	
///			Firmware version (NULL terminated)
///
///	\param	[IN] sizeBuffer:
///			Size of buffer provided for the firmware version.  
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds
///
/// \return	See ::SWI_RCODE for additional information.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetFirmwareVersion(LPTSTR szFWVersion, 
										U32 sizeBuffer, 
										U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function returns the date the device's firmware was created.
///			
/// \param	[OUT] szBuildDate:
///			Firmware build date.  The firmware build date string is in the form
///			of MM/DD/YY.
///
///	\param	[IN] sizeBuffer:
///			Size of buffer provided for the firmware build date
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds
///
/// \return	See ::SWI_RCODE for additional information.	
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetFirmwareBuildDate(LPTSTR szBuildDate, 
										  U32 sizeBuffer, 
										  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function returns the device's hardware version in a string.
///			
/// \param	[OUT] szHWVersion:	
///			Hardware version (NULL terminated).  The firmware version string
///			varies in length. It is recommended that a character string of 80
///			characters be allocated to store this return value.  The returned
///			string is null terminated.
///
///	\param	[IN] sizeBuffer:
///			Size of buffer provided for the hardware version
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds
///
/// \return	See ::SWI_RCODE for additional information.	
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetHardwareVersion(LPTSTR szHWVersion, 
										U32 sizeBuffer, 
										U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function returns the device's firmware loader version in a string. 
///			
/// \param	[OUT] szBVVersion:	
///			Bootloader version (NULL terminated).  The version string varies
///			in length. It is recommended that a character string of 80
///			characters be allocated to store this return value.
///
///	\param	[IN] sizeBuffer:
///			Size of buffer provided for the bootloader version
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds
///
/// \return	See ::SWI_RCODE for additional information.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetBootVersion(LPTSTR szBVVersion, 
									U32 sizeBuffer, 
									U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the USB descriptor build information.
///			
/// \param	[OUT] pUsbd:	
///			Structure to store USB descriptor build information
///
/// \return	See ::SWI_RCODE for additional information.
/// 
/// \sa SWI_STRUCT_UsbdInfo
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetUsbdInfo(SWI_STRUCT_UsbdInfo* pUsbdInfo, U32 Timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the boot loader build date.
///			
/// \param	[OUT] lpstrBLBldDate:
///			Pointer to store the build date information
///
///	\param [IN/OUT] nLength:
///			Size of buffer available to store the build date 
///			information/required buffer space
///
///	\param [IN] Timeout:	
///			Response timeout value in milliseconds
///
/// \return	SWI_RCODE_SMALL_BUF is returned if the specified buffer is not
///			large enough to store the entire build date information.  Check
///			nLength to see the required buffer size.  
///
///	\return	See ::SWI_RCODE for additional information.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetBootloaderBuildDate(LPTSTR lpstrBLBldDate,
											U32 &nLength, 
											U32 Timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve PRI information of the device.
///			
/// \param	[OUT] pPriInfo:
///			Pointer to a SWI_STRUCT_PriInfo to store the PRI information.
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return ::SWI_RCODE_OK:
///			The request has been received.
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_PriInfo
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetPriInfo(SWI_STRUCT_PriInfo* pPriInfo, U32 timeout);
											
///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve firmware flash information from the 
/// device.
///			
/// \param	[IN/OUT] pFlashImgInfo:
///			Pointer to a SWI_STRUCT_FlashImgInfo which specifies the flash
///			image type to retrieve.  This structure also contains the flash
///			image information returned from the device.  See 
///			SWI_STRUCT_FlashImgInfo for additional information.
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return ::SWI_RCODE_OK:
///			The device has received the request.  See 
///			SWI_STRUCT_FlashImgInfo::eResult for actual request result.
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_FlashImgInfo
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetFlashImgInfo(SWI_STRUCT_FlashImgInfo* pFlashImgInfo, 
									 U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to perform a soft modem reset.
/// 
/// ::SWI_NOTIFY_Reset is generated after the reset has completed.  Note that the
/// driver may also unload and reload when a modem reset occurs.  
/// ::SWI_NOTIFY_AirServerChange notifications are also generated in this 
/// scenario.
///
/// \return	See ::SWI_RCODE for additional information.
///
/// \sa SWI_NOTIFY_Reset
/// \sa SWI_NOTIFY_AirServerChange
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSoftModemReset();

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to perform a hard reset of the modem.  The driver 
/// will attempt to perform a hardware reset.
///			
/// Only supported on AirCard 710, AirCard 750, AirCard 775, AirCard 850, and 
/// AirCard 860 devices.  New devices will ignore this command.  Use 
/// ::SwiSoftModemReset to perform a soft reset.    
///
/// \param	[IN] timeout:	
///			Response timeout value in milliseconds to use (default 1 second).
///
/// \return	::SWI_RCODE_OK:
///			The request has been received.  
///
/// \return See ::SWI_RCODE for other error return codes.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiModemReset(U32 timeout = 1000);

/*@}*/ // End of modem information group

/** 
 * \defgroup GroupErrHand Error Handling
 */
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve information about the last error that 
/// occurred during a modem control and status transaction.
///
/// \param	[OUT] szError:
///			Buffer to store transaction error.  Recommended length for the
///			buffer is 256 bytes.
///
///	\param	[IN] sizeBuffer:	
///			length of buffer provided for the CnS transaction error
///
/// \return None 
///
///////////////////////////////////////////////////////////////////////////////
SWI_API void SwiGetLastError(LPTSTR szError, U32 sizeBuffer);

/*@}*/ // End of error handling group

/** 
 * \defgroup GroupNetwork Network Management and Status
 */
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the roaming state.  The modem is
/// either roaming or on the home network.
///
/// If this function is called while the modem is not in coverage, it will
/// report being at home. The modem cannot verify that you are roaming until 
/// it can detect coverage and identify the carrier(s).  Use of this function
/// should be limited. There is a notification available in the GPRS API
/// (::SWI_NOTIFY_NetworkStatus) that reports this data along with other useful
/// service parameters. Use of notifications is preferred over direct polling.
///
/// \param	[OUT] eRoaming:		
///			Current ::SWI_TYPE_RoamingState enumeration roaming state.
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds
///
/// \return	See ::SWI_RCODE for additional information.
///
/// \sa SWI_TYPE_RoamingState	
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetRoamingState(SWI_TYPE_RoamingState *eRoaming, 
									 U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function reports the current service provider's identification code.  
///
/// The provider ID for GPRS is a string provided by the carrier, over the 
///	air. The length of the string can be up to 17 characters long.  If this 
///	function is called while outside of coverage or not in service with a 
///	carrier, the function returns a null string and the OK result.  Use 
///	::SwiGetServiceStatusEx to confirm coverage.
///			
/// \param	[OUT] szName:
///			Network provider name (NULL terminated)
///
///	\param	[IN] sizeBuffer:
///			Size of buffer provided for the network provider name
///
///	\param	[IN] timeout:		
///			Response timeout value in milliseconds
///
/// \return	See ::SWI_RCODE for additional information.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetNetworkProviderID(LPTSTR szName, 
										  U32 sizeBuffer, 
										  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to determine the current radio band(s) the device is
/// currently using.
/// 
/// This object replaces ::SwiGetBandInfo.
///
///	For GSM/WCDMA devices and CDMA/EVDO devices operating in non-hybrid
///	mode operation, only one band is supported at a time.  In these
///	cases, the band info list will only contain a single entry.
///			
/// \param	[OUT] pRadioBand:	
///			Pointer to a SWI_STRUCT_RadioBandList structure to store the
///			list of current radio bands/
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_RadioBandList		
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetCurrentRadioBand(SWI_STRUCT_RadioBandList* pRadioBand, 
										 U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the current radio band setting of the
/// device along with the list of all the device supported radio bands.
///
/// This object replaces ::SwiGetBandInfo.
///			
/// \param	[OUT] pRadioBand:	
///			A pointer to a SWI_STRUCT_RadioBandConfig structure to store
///			the current radio band configuration.
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_RadioBandConfig		
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetRadioBandCfg(SWI_STRUCT_RadioBandConfig* pRadioBand, 
									 U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to request a new radio band setting.
/// 
/// This object replaces ::SwiSetBandInfo.
///
/// Setting the frequency band may cause a modem reset.  The caller
///	should use ::SwiGetRadioBandCfg to retrieve the list of supported bands
///	before calling ::SwiSetRadioBandCfg.
///			
/// \param	[IN] nRadioBandGroup:	
///			A bit mask value which specifies the radio band group to use.  See 
///			SWI_RADIOBANDGROUP_xxx definitions.
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_RADIOBANDGROUP_xxx		
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetRadioBandCfg(const U64 nRadioBandGroup, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is called to retrieve network traffic statistics 
///	(the number of bytes transmitted and received).
///
/// The traffic counters are reset to zero when the connection is dropped. 
/// While disconnected, this will report zeros.  The traffic count is user 
/// payload data only and does not include network housekeeping traffic or
/// SMS messages.
///			
/// \param	[OUT] nSent:	
///			Number of bytes sent
///
///	\param	[OUT] nReceived:
///			Number of bytes received
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	See ::SWI_RCODE for additional information.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetTrafficStatistics(U32 *nSent, 
										  U32 *nReceived, 
										  U32 Timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is called to optimize Window's TCP stack to improve
///	wireless transfer performance with the modem.  
///
/// This request modifies Window's registry values.
///			
/// \param	[IN] sTcpOpt:
///			SWI_STRUCT_TcpOpt structure containing TCP optimizations
///
/// \return	See ::SWI_RCODE for additional information.
///	    
/// \sa SWI_STRUCT_TcpOpt
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiOptimizeTcp(SWI_STRUCT_TcpOpt sTcpOpt);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is called to retrieve the Window's TCP stack optimization
/// values.    
///			
/// \param	[OUT] sTcpOpt:	
///			Structure to store TCP optimization settings
///
/// \return	See ::SWI_RCODE for additional information.
///
/// \sa SWI_STRUCT_TcpOpt
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetTcpOpt(SWI_STRUCT_TcpOpt &sTcpOpt);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the system time on the device.
/// 
/// This call will return an error (::SWI_RCODE_REQUEST_REJECTED) if the device
/// has not received a time update from the network.
///			
/// \param	[OUT] pDeviceTime:	
///			Pointer to a SWI_STRUCT_DeviceTime structure to store the system
///			time from the device.
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been received.
/// 
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_DeviceTime
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetDeviceTime(SWI_STRUCT_DeviceTime* pDeviceTime, 
								   U32 timeout);

/*@}*/ // End of network management and status group

/** 
 *  Audio Profiles
 */
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to get the currently used audio profile.
/// 
/// A device may support multiple audio profiles.
///			
/// \param	[OUT] pAudioProfile:	
///			Pointer to a SWI_STRUCT_AudioProfile structure which contains the
///			audio profile currently used.
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been received.
///
///	\return	See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_STRUCT_AudioProfile
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetAudioProfile(SWI_STRUCT_AudioProfile* pAudioProfile, 
									 U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to configure the currently used audio profile.
/// 
/// A device may support multiple audio profiles.  ::SWI_NOTIFY_AudioProfile
///	notification is sent anytime the audio profile is changed.
///			
/// \param	[IN] pAudioProfile:	
///			Pointer to a SWI_STRUCT_AudioProfile structure which contains
///			the audio profile to configure.
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return ::SWI_RCODE_OK:
///			The request has been received.
///
/// \return See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_STRUCT_AudioProfile
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetAudioProfile(SWI_STRUCT_AudioProfile* pAudioProfile, 
									 U32 timeout);

/*@}*/ // End of call management and voice features

/** 
 * \defgroup GroupRadioMgmt Radio Power and Status
 */
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the current radio power mode.
///			
/// \param	[OUT] pRadioPower:	
///			Pointer to a SWI_STRUCT_RadioPower structure to store the current
///			radio power setting.
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return	See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_STRUCT_RadioPower
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetRadioPower(SWI_STRUCT_RadioPower* pRadioPower, 
								   U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to configure the radio power mode.
///			
/// \param	[IN] pRadioPower:	
///			A pointer to a SWI_STRUCT_RadioPower structure which specifies the
///			the new radio power setting.
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_STRUCT_RadioPower
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetRadioPower(const SWI_STRUCT_RadioPower* pRadioPower, 
								   U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the current radio temperature state.
/// 
/// UMTS AirCards will always report that the temperature state is normal.
///	Temperature state changes can be monitored with ::SWI_NOTIFY_RadioTempState.
///			
/// \param	[OUT] pRadioTemp:	
///			Pointer to a SWI_STRUCT_RadioTempState to store the current
///			radio temperature state.
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_RadioTempState
/// \sa SWI_NOTIFY_RadioTempState	
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetRadioTempState(SWI_STRUCT_RadioTempState* pRadioTemp, 
									   U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the current radio battery state.
///
/// Voltage changes can be monitored with ::SWI_NOTIFY_RadioBattery.
///			
/// \param	[OUT] pRadioBattery:
///			A pointer to a SWI_STRUCT_RadioBattery structure to store the
///			current radio battery state.
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_RadioBattery
/// \sa SWI_NOTIFY_RadioBattery
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetRadioBattery(SWI_STRUCT_RadioBattery* pRadioBattery,
									 U32 timeout);

/*@}*/ // End of radio power and status

/**
 * \defgroup GroupLbs Location Based Services
 */
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to initiate a location fix.
/// 
/// If the location fix initiation is successful, the following notifications
/// will inform the host of the location fix progress and termination:
///
///		- ::SWI_NOTIFY_LbsPdDone
///		- ::SWI_NOTIFY_LbsPdData
///		- ::SWI_NOTIFY_LbsPdEnd
///		- ::SWI_NOTIFY_LbsPdBegin
///		- ::SWI_NOTIFY_LbsPdUpdateFailure
///		- ::SWI_NOTIFY_LbsSatInfo
///				
/// \param	[IN] psLbsPdGetPos:	
///			A pointer to a SWI_STRUCT_LbsPdGetPos structure which contains the
///			location fix configuration.
///
///	\param	[IN] timeout:		
///			Function timeout in milliseconds.
///
/// \return SWI_RCODE_OK is returned if the modem is able to initiate a 
///			location fix.  
///
///	\return	If the modem is unable to initiate the location fix, an error
///			code will be returned.  See SwiRcodes.h for additional information.	
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetLbsPdGetPos(
					const SWI_STRUCT_LbsPdGetPos *psLbsPdGetPos, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function requests that the modem provide the current status of the 
/// LBS.
///				
/// \param	[IN] psLbsPdGetStatus:	
///			A pointer to a SWI_STRUCT_LbsPdGetStatus structure which contains
///			the current status of the LBS.
///
///	\param	[IN] timeout:			
///			Function timeout in milliseconds.
///
/// \return See ::SWI_RCODE for additional information.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetLbsPdStatus(
					SWI_STRUCT_LbsPdGetStatus *psLbsPdGetStatus, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function requests that the modem start a tracking session.
/// 
/// If the track session was initiated successfully, the following 
///	notifications will inform the host of the location fix progress and 
/// termination:
///
///		- ::SWI_NOTIFY_LbsPdDone
///		- ::SWI_NOTIFY_LbsPdData
///		- ::SWI_NOTIFY_LbsPdEnd
///		- ::SWI_NOTIFY_LbsPdBegin
///		- ::SWI_NOTIFY_LbsPdUpdateFailure
///		- ::SWI_NOTIFY_LbsSatInfo
///
///	This command should be used when an application requires multiple
///	location fixes over a small period of time (ex. a fix between every 1 to
/// 240 seconds).
///
///	Due to the potential need for first updating the ephemeris, almanac 
/// and/or location data, the "time to first fix" may require more time than 
/// the subsequent fixes.  Tracking applications need to consider this possible
/// initial delay and may want to behave "pro actively" by initiating a Data
/// Download session and/or a single location fix as part of their startup 
/// sequence.  As a guideline, almanac data is valid for 3 to 4 days, 
/// ephemeris data is valid for 30 to 120 minutes, coarse location data is 
/// valid for 4 minutes.
///				
/// \param	[IN] psLbsPdTrack:	
///			A pointer to a SWI_STRUCT_LbsPdTrack structure which contains
///			the track session configuration.
///
///	\param	[IN] timeout:
/// 		Function timeout in milliseconds.
///
/// \return ::SWI_RCODE_OK is returned if the modem is able to initiate a 
///			location fix.  
///
///	\return	If the modem is unable to initiate the location fix, an error
///			code will be returned.  See SwiRcodes.h for additional 
///			information.	
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetLbsPdTrack(const SWI_STRUCT_LbsPdTrack *psLbsPdTrack, 
								   U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to end current LBS tracking session.
/// 
/// This API will respond with a ::SWI_NOTIFY_LbsPdDone/::SWI_NOTIFY_LbsPdEnd 
/// notification that includes the End status.
///
///	There may be one of each type of session active simultaneously.
///				
/// \param	[IN] psLbsPdEndSession:	
///			A pointer to a SWI_STRUCT_LbsPdEndSession structure which contains
///			the current tracking session to terminate.
///
///	\param	[IN] timeout:			
///			Function timeout in milliseconds.
///
/// \return See ::SWI_RCODE for additional information.	
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetLbsPdEndSession(
					const SWI_STRUCT_LbsPdEndSession *psLbsPdEndSession, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function requests the modem's default parameter settings.
///				
/// \param	[OUT] psLbsPdGetParam:	
///			A pointer to a SWI_STRUCT_LbsPaGetParam structure which contains
///			the position determination parameters.
///
///	\param	[IN] timeout:	
///			Function timeout in milliseconds.
///
/// \return See ::SWI_RCODE for additional information.	
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetLbsPaParam(SWI_STRUCT_LbsPaGetParam *psLbsPdGetParam, 
								   U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function gets the results of the position fix.
///				
/// \param	[OUT] psLbsPdData:	
///			A pointer to a SWI_STRUCT_LbsPdData structure which contains the
///			position fix results.
///
///	\param	[IN] timeout:		
///			Function timeout in milliseconds.
///
/// \return An error will be returned if there is no position fix information
///			to report.  See ::SWI_RCODE for additional information.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetLbsPdData(SWI_STRUCT_LbsPdData *psLbsPdData, 
								  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to get GPS IP Address settings from the modem.
/// 
/// The PDE IP Address is a write only field and is not to be displayed to
///	users.  This API will return:
///		- 0.0.0.0         : The IP address is 0.0.0.0 or PDE NV Item is inactive
///						    (GPS not supported).
///		- 255.255.255.255 : The device has valid PDE IP address. 
///		- IP Address      : The device is internally unlocked and will return
///							the true address.
///				
/// \param	[OUT] psPaIpAddr:	
///			A pointer to a SWI_STRUCT_LbsPaIpAddr structure which contains the
///			TCP/IP address information.
///
///	\param	[IN] timeout:
///         Function timeout in milliseconds.
///
/// \return See ::SWI_RCODE for additional information.	
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetLbsPaIpAddr(SWI_STRUCT_LbsPaIpAddr *psPaIpAddr,
									U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to set current GPS IP Address.
///				
/// \param	[IN] psPaIpAddr:	
///			A pointer to a SWI_STRUCT_LbsPaIpAddr structure which contains the
///			TCP/IP address information.
///
///	\param	[IN] timeout:    
///			Function timeout in milliseconds.
///
/// \return See ::SWI_RCODE for additional information.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetLbsPaIpAddr(const SWI_STRUCT_LbsPaIpAddr *psPaIpAddr, 
									U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to get the GPS port ID used in LBS sessions.
///				
/// \param	[OUT] psPaPortId:	
///			A pointer to a SWI_STRUCT_LbsPaPortId structure which contains the
///			port ID.
///
///	\param	[IN] timeout:       
///			Function timeout in milliseconds.
///
/// \return See ::SWI_RCODE for additional information.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetLbsPaPortId(SWI_STRUCT_LbsPaPortId *psPaPortId, 
									U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to set the GPS port ID used in LBS sessions.
///				
/// \param	[IN] psPAPortID:	
///			A pointer to a SWI_STRUCT_LbsPaPortId structure which contains the
///			port ID.
///
///	\param	[IN] timeout:
///			Function timeout in milliseconds.
///
/// \return See ::SWI_RCODE for additional information.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetLbsPaPortId(const SWI_STRUCT_LbsPaPortId *psPAPortID, 
								   U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// Use this function to start Keep Warm processing.
/// 
/// This downloads GPS assistance data over the network.  The status of the 
/// process can be monitored using:
///		- ::SWI_NOTIFY_LbsPaWarmBegin
///		- ::SWI_NOTIFY_LbsPaWarmStatus
///		- ::SWI_NOTIFY_LbsPaWarmDone	
///				
/// \param	[IN] timeout:	
///			Function timeout in milliseconds.
///
/// \return See ::SWI_RCODE for additional information.					
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetLbsPaKeepWarmStart(U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// Use this function to get the Keep Warm processing status.
///				
/// \param	[OUT] psLbsPaWarmStatus:	
///			A pointer to a SWI_STRUCT_LbsPaWarmStatus structure which 
///			contains warm status information.
///
///	\param	[IN] timeout:			
///			Function timeout in milliseconds.
///
/// \return See ::SWI_RCODE for additional information.				
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetLbsPaWarmStatus(
					SWI_STRUCT_LbsPaWarmStatus *psLbsPaWarmStatus, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// Use this function to stop the Keep Warm processing.
/// 
/// ::SWI_NOTIFY_LbsPaWarmDone is generated when the process completes.
///				
/// \param	[IN] timeout:	
///			Function timeout in milliseconds.
///
/// \return ::SWI_RCODE_OK indicates that the modem has successfully received
///			the stop request.  A ::SWI_NOTIFY_LbsPaWarmDone notification is sent
///			the the actually process terminates.  
///
///	\return See ::SWI_RCODE for additional information.
///
/// \sa SWI_NOTIFY_LbsPaWarmDone		
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetLbsPaKeepWarmStop(U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// Use this function to get current GPS satellite information.
///				
/// \param	[OUT] psSatInfo:	
///			A pointer to a SWI_STRUCT_LbsSatInfo structure which contains
///			satellite information.
///
///	\param	[IN] timeout:	
///			Function timeout in milliseconds.
///
/// \return See ::SWI_RCODE for additional information.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetLbsSatInfo(SWI_STRUCT_LbsSatInfo *psSatInfo, 
								   U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function requests that the modem clear various location parameters to 
/// simulate a cold start.
///				
/// \param	[IN] psLbsClearAssistance:	
///			A pointer to a SWI_STRUCT_LbsClearAssistance structure which
///			contains parameters to clear.
///
///	\param	[IN] timeout:	
///			Function timeout in milliseconds.
///
/// \return See ::SWI_RCODE for additional information.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetLbsClearAssistance(
					const SWI_STRUCT_LbsClearAssistance *psLbsClearAssistance, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// Use this function to retrieve location fix settings stored on the device.
///				
/// \param	[OUT] psLbsSettings:	
///			A pointer to a SWI_STRUCT_LbsFixSettings structure which contains
///			location fix settings.
///
///	\param	[IN] timeout:		
///			Function timeout in milliseconds.
///
/// \return ::SWI_RCODE_OK indicates that the modem has received the request.
///
///	\return	See SWI_STRUCT_LbsFixSettings for actual results of the 
///			transaction.
///
///	\return	See ::SWI_RCODE for additional information.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetLbsFixSettings(
					SWI_STRUCT_LbsFixSettings *psLbsFixSettings, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// Use this function to change location fix settings stored on the device.
///				
/// \param	[IN] psLbsSettings:	
///			A pointer to a SWI_STRUCT_LbsFixSettings structure which contains
///			location fix settings.
///
///	\param	[IN] timeout:		
///			Function timeout in milliseconds.
///
/// \return ::SWI_RCODE_OK indicates that the modem has received the request.
///
///	\return See SWI_STRUCT_LbsFixSettings for actual results of the 
///			transaction.
///
/// \return	See ::SWI_RCODE for additional information.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetLbsFixSettings(
					SWI_STRUCT_LbsFixSettings *psLbsFixSettings, 
					U32 timeout);
					
///////////////////////////////////////////////////////////////////////////////
///
/// Use this function to respond to a network initiated location fix request.
/// 
/// The host is notified of a network initiated location fix request via
/// ::SWI_NOTIFY_LbsNiReq.  
///				
/// \param	[IN/OUT] pLbsNiReq:	
///			A pointer to a SWI_STRUCT_LbsNiReq structure which contains
///			network initiated request information.
///
///	\param	[IN] timeout:		
///			Function timeout in milliseconds.
///
/// \return SWI_RCODE_OK indicates that the modem has received the request.
///
///	\return See SWI_STRUCT_LbsNiReq::eErrCode for actual results of the 
///			transaction.
///
/// \return	See ::SWI_RCODE for additional information.
/// 
/// \sa SWI_STRUCT_LbsNiReq
/// \sa SWI_NOTIFY_LbsNiReq
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetLbsNiReq(SWI_STRUCT_LbsNiReq *pLbsNiReq, U32 timeout);

/*@}*/ // End of LBS group

/**
 * \defgroup GroupDriver Driver
 */
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to get the name of the driver interface in use.
/// 
/// This command only works with devices using the network adapter interface.
///			
/// \param	[OUT] pstrServiceName:	
///			Buffer to store the service name
///
///	\param	[IN/OUT] nSize:			
///			Maximum service name length/required length.
///
/// \return	::SWI_RCODE_OK:
///			Service name successfully retrieved
///
///	\return	::SWI_RCODE_SMALL_BUF:
///			Buffer provided is not big enough.  nSize contains the
///			required buffer size.	
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetServiceName(LPTSTR pstrServiceName, U32 &nSize);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the NDIS driver version.
/// 
/// This command only works with devices using the network adapter interface.
///
///	\param	[OUT] szDriverVersion:	
///			A NULL terminated string containing the NDIS driver version.
///
///	\param	[IN] szLength:			
///			Length of buffer provided for the NDIS driver version.  A
///			recommended buffer size of 100 bytes is recommended.
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK
///			The request has been received by the modem.
///
///	\return	::SWI_RCODE_REQUEST_TIMEOUT:
///			The  request has timed out.
///
///	\return See ::SWI_RCODE for other error return codes.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetDriverVersion(LPTSTR szDriverVersion, 
									  U32 szLength, 
									  U32 timeout);

/*@}*/ // End of driver group

#ifdef __cplusplus
} ///extern "C" {
#endif

#endif __SWIAPI_CM
