
///////////////////////////////////////////////////////////////////////////////
//                                                                           
//	$Revision: 17 $																
//																				
//	Name       : SwiApiGsm.h													
//                                                                             
//  Purpose    : SWI GPRS specific SDK API										
//					                                                           
//	Copyright (c) 2008 Sierra Wireless, Inc.  All rights reserved			    
//                                                                              
///////////////////////////////////////////////////////////////////////////////
#ifndef __SWI_API_GSM_H
#define __SWI_API_GSM_H

#ifdef __cplusplus
extern "C" {
#endif

#include "SwiApiMpGsm.h"
#include "SwiStructsGsm.h"

/** 
 *	\addtogroup GroupModemInfo Modem Information and Management
 */
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// This function returns the modem On/Off state.  
/// 
/// The modem disable setting will persist though the modem's power may be 
/// cycled.
/// 
/// This function is only supported on GSM devices.  
///			
/// \param	[OUT] pModemDisable:	
///			True is returned if the modem is disabled, false otherwise.
///
///	\param	[IN] timeout:		
///			Response timeout value in milliseconds.
///
/// \return ::SWI_RCODE_OK:
///			The disable modem setting has been returned from the modem.
///			
/// \return See ::SWI_RCODE for other error return codes.
/// 
/// \sa SwiSetModemDisable
/// \sa SWI_NOTIFY_ModemDisabled
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetModemDisable(bool* pModemDisable, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function can be used to change the modem disable setting on the modem.  
/// 
/// The modem disable setting will persist though the modem's power may be
/// cycled.  Switching modem state from OFF to ON may result in a modem reset.
///			
/// This function is only supported on GSM devices.
///
/// \param	[IN] bModemDisable:	
///			- Specify true to disable the modem.
///			- Specify false to enable the modem.
///
///	\param	[IN] timeout:		
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK indicates the request was received by the 
///			modem.  The result of the request is indicated in a 
///			::SWI_NOTIFY_ModemDisabled notification .
///			
/// \return See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_NOTIFY_ModemDisabled
/// \sa SwiGetModemDisable
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetModemDisable(const bool bModemDisable, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function controls the radio power state.
/// 
/// This function is similar to SwiSetModemDisable.  When called to "shutdown"
/// the radio, the modem will detach from the network and power down the radio.
/// Unlike ::SwiSetModemDisable, however, this powered down state is NOT 
/// persistent across modem power cycles.
/// 
/// When called to "startup" the radio, the modem will power on the radio and
/// attempt to attach to a network (if available).
/// 
/// It is recommended that this function be called with the "shutdown" 
/// parameter when the host application shuts down or when the PC enters a 
/// suspend state.
/// 
/// It is recommended that this function be called with the "startup" parameter
/// when the host application initially starts up and after resuming from
/// a PC suspend state.
///
/// A change in the radio's power state will be signaled with a
/// ::SWI_NOTIFY_ModemDisabled indication.
///
/// This function is only supported on GSM devices.
///			
/// \param	[IN] bStartup:	
///			Set to true to power up the radio and attempt to attach to a 
///			network (if available).  Set to false to detach from the network
///			and power down the radio.
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds.
///
/// \return ::SWI_RCODE_OK:
///			The request was received by the modem.  The result of the request
///			is indicated in a ::SWI_NOTIFY_ModemDisabled notification.
///
/// \return See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_NOTIFY_ModemDisabled
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetHostStartup(bool bStartup, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to inform the modem when the host software 
/// application has launched.
///
/// This function is only supported on GSM devices.
///   		
/// \param	[IN] timeout:
///			Response timeout value in milliseconds
///
/// \return ::SWI_RCODE_OK:
///			The request was received by the modem.
///
/// \return See ::SWI_RCODE for other error return codes.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiHostAppLaunch(U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to fetch the International Mobile Equipment Identity 
/// (IMEI) from the modem.  The IMEI consists of:
///		- Type Approval Code (TAC)
///		- Final Assembly Code (FAC)
///		- Serial Number (SNR)
///
/// This function is only supported on GSM devices.
///
/// \param	[OUT] pImei:		
///			IMEI
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_STRUCT_Imei
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetImei(SWI_STRUCT_Imei *pImei, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the Factory Serial Number (FSN).  The 
/// FSN contains information such as the manufacturing date, a unique serial
/// number for each modem and the hardware version.
///
/// This function is only supported on GSM devices.
///
/// \param	[OUT] sFsn:
///			Factory Serial Number
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_STRUCT_Fsn
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetSerialNumber(SWI_STRUCT_Fsn *sFsn, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the FPGA version.
///
/// This function is only supported on GSM devices.  
/// 
/// \param	[OUT] major:			
///			FPGA major version
///
///	\param	[OUT] minor:
///			FPGA minor version
///
///	\param	[IN] timeout:		
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetFPGAVersion(U32 *major, U32 *minor, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the modem's available features. 
/// 
/// This function replaces SwiGetAvailableFeature.
///
/// This function is only supported on GSM devices. 
///			
/// \param	[OUT] sFeatures:
///			Feature capability.  See SWI_STRUCT_AvailFeatures for details.
///
/// \param	[IN] timeout
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_STRUCT_AvailFeatures
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetAvailableFeatures(SWI_STRUCT_AvailFeatures& sFeatures, 
										  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the modem's customizable features.
///
/// This function is only supported on GSM devices.
///			
///	\param	[OUT] sCustomizations
///			Modem feature customizations.
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_FeatureCustomizations
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetFeatureCustomizations(
					SWI_STRUCT_FeatureCustomizations* sCustomizations, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to query the modem for its device type.
///
///	This is a legacy function.  ::SwiGetAvailAirServers and ::SwiSelectAirServer
/// should now be used to determine available devices and selecting a 
/// device to communicate with.	
///
/// This function is only supported on GSM devices.
///
/// \param	[OUT] pAirCardType:
///			Card type
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_AirCardType
/// \sa SwiGetAvailAirServers
/// \sa SwiSelectAirServer
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetAirCardType(SWI_STRUCT_AirCardType *pAirCardType, 
									U32 timeout);
									
/*@}*/	// End of modem information and management group

/** 
 *	\addtogroup GroupNotif	Notifications
 */
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to stop the modem from sending all notifications. 
///
/// This function is only supported on GSM devices. 
///			
/// \param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been received by the modem.  
///
///	\return	See ::SWI_RCODE for other error return codes.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiStopAllNotif(U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to enable a list of notifications simultaneously.
///
/// This function is only supported on GSM devices. 
///			
/// \param	[IN] psList:
///			List of notifications to enable.  See SWI_TYPE_Notify for a 
///			complete list of notifications.  Only GSM notifications work with
///			this function.
///
/// \param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been successfully processed by the modem.  
///
///	\return	See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_STRUCT_NotifyList
/// \sa SWI_TYPE_Notify
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiEnableNotif(SWI_STRUCT_NotifList *psList, U32 timeout);

/*@}*/	// End of notification group

/** 
 *	\addtogroup GroupNetwork Network Management and Status
 */
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// This function retrieves the identifier of the cell currently being used 
/// by the modem. 
/// 
/// The Cell ID reported is a numeric value. This information is usually only 
/// meaningful to technicians for support purposes.  In the future there may 
/// be some application of this for locating the device on a map.  Use of this 
/// function should be limited. There is a notification available in the GPRS 
/// API (::SWI_NOTIFY_NetworkStatus or SWI_STRUCT_GsmSystemStatus) that 
/// reports this data along with other useful service parameters.  Use of
/// notifications is preferred over direct polling.
///
/// This function is only supported on GSM devices.
///			
/// \param	[OUT] nCellID:
///			Current cell ID
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_STRUCT_GsmSystemStatus
/// \sa SWI_NOTIFY_NetworkStatus
///
/////////////////////////////////////////////////////////////////////////////// 
SWI_API SWI_RCODE SwiGetCellID(U32* nCellID, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function maps RSSI values to the number of RSSI bars that should
/// be shown to the user.  It will output 0 to 5 RSSI bars.  
///
/// This function is only supported on GSM devices.  
///			
/// \param	[IN] iRssi:
///			RSSI value in dBm to be converted to number of RSSI bars.
///
///	\param	[OUT] pNumBars:
///			Number of RSSI bars to be displayed.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
/// 
/// \return ::SWI_RCODE_INVALID_PAR:
///			Invalid RRSI value was supplied.
///
///	\return	See ::SWI_RCODE for other error return codes.
/// 
/// \sa To get the RSSI value in dBm, call ::SwiGetRssiBer. 
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetRssiBars(const I32 iRssi, U32 *pNumBars);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to fetch the current received signal strength
/// indication (RSSI) and bit error rate (BER) from the modem.  
/// 
/// The RSSI values are measured in dBm.  A return value approaching -110
/// indicates that the modem is outside of coverage or the signal is weak.
///
/// Use of this function should be reserved to application startup. There is a 
/// notification available in the GPRS API (::SWI_NOTIFY_Rssi) that also 
/// includes a measure of the Block Error Rate (BER).  Use of notifications is 
/// preferred over direct polling.
///
/// This function is only supported on GSM devices.
///			
/// \param	[OUT] sRssiBer: 
///			RSSI and BER values
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_Rssi
/// \sa SWI_NOTIFY_Rssi
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetRssiBer(SWI_STRUCT_Rssi *sRssiBer, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function requests the current service status from the modem.
/// 
/// Use of this function should be limited. There is a notification available 
/// in the GPRS API (::SWI_NOTIFY_NetworkStatus or 
/// ::SWI_NOTIFY_GsmSystemStatus) that reports this data along with other 
/// useful service parameters.  Use of notifications is preferred over direct
/// polling.
///
/// This function is only supported on GSM devices.
///			
/// \param	[OUT] eServiceStatus:
///			Service status
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_TYPE_ServiceStatus
/// \sa SWI_STRUCT_GsmSystemStatus
/// \sa SWI_NOTIFY_NetworkStatus
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetServiceStatusEx(SWI_TYPE_ServiceStatus *eServiceStatus, 
										U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to reset the modem's byte data counters.   
/// 
/// If not explicitly reset, byte counter information is persistent across
/// PDP context activations.
///
/// This function is only supported on GSM devices.
///			
/// \param	[IN] timeout:	
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// Notes:	None
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiResetTrafficStatistics(U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is no longer supported.
/// 
/// This function is used to fetch the packet roaming disable setting of
/// the modem.  If packet roaming is disabled then packet service will be
/// prevented when the modem is not on the home network.
///
/// This function is only supported on GSM devices.
///			
/// \param	[OUT] bDisable:	
///			True if packet service is disabled when roaming.
///			False if packet service is never disabled.
///
/// \param	[IN] timeout:	
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
/// 
/// /sa Use SwiSetRoamingDisable to change the packet roaming disable setting
///		on the modem.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetRoamingDisable(bool *bDisable, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is no longer supported. 
/// 
/// This function is used to set the packet roaming disable setting on the 
/// modem.  If packet roaming is disabled then packet service will be prevented
/// when the modem is not on the home network.  
///
/// This function is only supported on GSM devices.
///			
/// \param	[IN] bDisable:	
///			Set to true to disable packet roaming.
///			Set to false to never disable packet roaming.
///
/// \param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SwiGetRoamingDisable
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetRoamingDisable(const bool bDisable, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to fetch the current frequency band and a list
/// of all bands supported by the modem.
/// 
/// With 3G products, the following set of band related objects should be used:
///		- SWI_STRUCT_RadioBandList
///		- SWI_STRUCT_RadioBandConfig
///		- ::SwiGetCurrentRadioBand
///		- ::SwiSetRadioBandCfg
///		- ::SwiGetRadioBandCfg
///
/// This function is only supported on GSM devices.
///			
/// \param	[OUT] sBandInfo: 
///			Modem band information.
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_RadioBandList
/// \sa SWI_STRUCT_RadioBandConfig
/// \sa SwiGetCurrentRadioBand
/// \sa SwiSetRadioBandCfg
/// \sa SwiGetRadioBandCfg
/// \sa SWI_STRUCT_Band
/// \sa SWI_TYPE_Band
/// \sa SWI_NOTIFY_Band
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetBandInfo(SWI_STRUCT_Band *sBandInfo, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to set the current frequency band.  
///
/// With 3G products, the following set of band related objects should be used:
///		- SWI_STRUCT_RadioBandList
///		- SWI_STRUCT_RadioBandConfig
///		- ::SwiGetCurrentRadioBand
///		- ::SwiSetRadioBandCfg
///		- ::SwiGetRadioBandCfg
/// 
/// Setting the frequency band may cause a modem reset.  The caller should 
/// use SwiGetBandInfo to retrieve the list of supported bands before 
/// calling ::SwiSetBandInfo.
///
/// This function is only supported on GSM devices.
///
///	\param	[IN] sBandInfo:  
///			New frequency band
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
///	\sa SWI_STRUCT_RadioBandList
/// \sa SWI_STRUCT_RadioBandConfig
/// \sa SwiGetCurrentRadioBand
/// \sa SwiSetRadioBandCfg
/// \sa SwiGetRadioBandCfg
/// \sa SWI_STRUCT_SetBand
/// \sa SWI_TYPE_Band
/// \sa SWI_NOTIFY_Band
/// \sa SWI_NOTIFY_BandWrite	
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetBandInfo(const SWI_STRUCT_SetBand *pBandInfo, 
								 U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to fetch the transmit speed from the modem.  The
/// transmit speed is determined by the number of time slots used for GPRS
/// transmit traffic.  The greater the number of slots the higher the maximum 
/// transmit speed. 
///
/// This function is only supported on GSM devices.
///
///	\param	[OUT] TransmitSpeed:  
///			Current number to transmit slots
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_TYPE_TransmitSpeed
/// \sa SwiSetTransmitSpeed
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetTransmitSpeed(SWI_TYPE_TransmitSpeed *TransmitSpeed, 
									  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to set the transmit speed on the modem.  The transmit 
/// speed is determined by the number of time slots used for GPRS transmit 
/// traffic.  The greater the number of slots the higher the maximum transmit 
/// speed.
/// 
/// Note that only requests the maximum number of slots the modem will use.
/// However, the network may allocate fewer.
///
/// This function is only supported on GSM devices.
///			
/// \param	[OUT] TransmitSpeed:  
///			Number to transmit slots
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed.
///
///	\return	See ::SWI_RCODE for other error return codes.  
///
/// \sa SWI_TYPE_TransmitSpeed
/// \sa SwiGetTransmitSpeed
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetTransmitSpeed(
					const SWI_TYPE_TransmitSpeed TransmitSpeed, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function retrieves the IP address of the current GPRS session from
/// the modem.     
///
/// This function is only supported on GSM devices.
///			
/// \param	[OUT] szIPAddress:  
///			IP address (NULL terminated)
///
///	\param	[IN] sizeBuffer:
///			Size of the buffer provided for the IP address
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
/// 
/// \sa SwiGetIPAddressEx
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetIPAddress(LPTSTR szIPAddress, 
								  U32 sizeBuffer, 
								  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function retrieves the IP address of the specified profile.  
///
/// This function is only supported on GSM devices. 
///
///	\param	[OUT] pIp:
///			IP address information.  ProfileId of the IP address structure must
///			be specified before calling this function.
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes. 
/// 
/// \sa SWI_STRUCT_IpAddress
/// \sa SwiGetIPAddress
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetIPAddressEx(SWI_STRUCT_IpAddress* pIp, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is obsolete and is replaced with ::SwiGetGsmSystemStatus.  
/// 
/// This function is used to fetch the network status of the modem.
/// 
/// ::SWI_NOTIFY_NetworkStatus indication is generated when there is a state
/// change.  This is the preferred method of monitoring status instead of 
/// polling with this function. 
///
/// This function is only supported on GSM devices.
///
///	\param	[OUT] sNetworkStatus:	
///			Network status
/// 
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes. 
///
/// \sa SwiGetGsmSystemStatus
/// \sa SWI_STRUCT_GSM_NetworkStatus
/// \sa SWI_NOTIFY_NetworkStatus
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetNetworkStatus(
					SWI_STRUCT_GSM_NetworkStatus *sNetworkStatus, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to fetch the packet session status of the modem.
///
/// ::SWI_NOTIFY_PktSessionStatus indication is generated when there is a state
/// change.  This is the preferred method of monitoring status instead of 
/// polling with this function. 
///
/// This function is only supported on GSM devices.
/// 
///	\param	[OUT] sSessionStatus:	
///			Packet session status
/// 
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes. 
///
/// \sa SWI_STRUCT_PktSessionStatus
/// \sa SWI_NOTIFY_PktSessionStatus
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetPktSessionStatus(
					SWI_STRUCT_PktSessionStatus *sSessionStatus, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to fetch the packet session status of the modem.
///
/// This function replaces the old API ::SwiGetPktSessionStatus()  
///
/// ::SWI_NOTIFY_PktSessionStatus indication is generated when there is a state
/// change.  This is the preferred method of monitoring status instead of 
/// polling with this function. 
///
/// This function is only supported on GSM devices.
/// 
/// \param  [IN/OUT] sSessionCall:        
///			Packet session status containing profileID
/// 
/// \param  [IN] timeout:   
///			Response timeout value in milliseconds
///
/// \return ::SWI_RCODE_OK:
///			The request has been processed and values returned 
///			are valid.
///
/// \return See ::SWI_RCODE for other error return codes. 
///
/// \sa SWI_STRUCT_PktSessionCall
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetPktSessionStatusEx(
					SWI_STRUCT_PktSessionCall *sSessionCall, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to fetch the PLMN selection mode of the modem.  
/// 
/// The modem PLMN selection mode will be either Automatic or Manual.
///
/// This function is only supported on GSM devices.
///
///	\param	[OUT] eMode:	
///			PLMN selection mode
/// 
///	\param	[OUT] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes. 
///
/// \sa SWI_TYPE_PLMN_Mode
/// \sa SwiSetPLMNMode
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetPLMNMode(SWI_TYPE_PLMN_Mode* eMode, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to set the PLMN selection mode of the modem. 
///	
/// The mode can be set to automatic or manual.  The PLMN must be specified
///	for the manual mode.  Use ::SwiStartPLMNSearch to search for a list of
/// available PLMNs before switching to manual mode. 
///
/// This function is only supported on GSM devices.
///
///	\param	[IN] sPlmn:		
///			PLMN selection mode information
/// 
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes. 
///
/// \sa SWI_STRUCT_PlmnSelection
/// \sa SwiGetPLMNMode
/// \sa SwiStartPLMNSearch
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetPLMNMode(const SWI_STRUCT_PlmnSelection sPlmn, 
								 U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to initiate a PLMN scan.  In general this is done
/// before switching to manual PLMN selection mode.  
/// 
/// This function should not be called until the ::SWI_NOTIFY_PlmnReady
/// notification has been received.  
///
/// This function is only supported on GSM devices.
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed.  The result of the request will be 
///			indicated in a SWI_NOTIFY_PlmnAvailable notification.  
///			SwiGetPLMNSelection() should be used to retrieve the list of PLMN 
///			found in the area as a result of the scan.
///
///	\return	See ::SWI_RCODE for other error return codes. 
///
/// \sa SWI_NOTIFY_PlmnAvailable
/// \sa SWI_NOTIFY_PlmnReady
/// \sa SwiGetPLMNSelection
/// \sa SwiSetPLMNMode
/// \sa SwiGetPLMNMode
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiStartPLMNSearch(U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// The PLMN scan initiated by ::SwiStartPLMNSearch compiles a list of PLMNs in 
/// the area.  This function is used to retrieve a single PLMN from that list.
///
/// This function is only supported on GSM devices.
///			
/// \param	[OUT] sPlmn:
///			PLMN information
///
/// \param	[IN] timeout:
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.  The
///			modem's response contains a single PLMNs information and will 
///			indicate if there are more PLMN to be retrieved from the list on
///			the modem.  See SWI_STRUCT_PlmnSelection for additional info.  If
///			there are additional PLMNs in the list, call ::SwiGetPLMNSelection 
///			repeatedly until all PLMNs are read.
///
///	\return	See ::SWI_RCODE for other error return codes. 
///
/// \sa SWI_NOTIFY_PlmnAvailable
/// \sa SwiStartPLMNSearch
/// \sa SWI_STRUCT_PlmnSelection
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetPLMNSelection(SWI_STRUCT_PlmnSelection* sPlmn, 
									  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the GSM system status.
/// 
/// This function replaces SwiGetNetworkStatus.
/// 
/// Use of this function should be limited.  ::SWI_NOTIFY_GsmSystemStatus 
/// notification is generated when there is a change in the system status
/// information.  Use of notifications is preferred over direct polling.
///
/// This function is only supported on GSM devices.
///			
/// \param	[OUT] pSysStatus:	
///			System status
///
/// \param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_GsmSystemStatus
/// \sa SWI_NOTIFY_GsmSystemStatus
/// \sa SwiGetNetworkStatus
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetGsmSystemStatus(SWI_STRUCT_GsmSystemStatus* pSysStatus,
										U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve GSM cell information.
///			
/// Use of this function should be limited.  ::SWI_NOTIFY_GsmCellInfo 
/// notification is generated when there is a change in the cell information.  
/// Use of notifications is preferred over direct polling.
///
/// This function is only supported on GSM devices.
///
/// \param	[OUT] pCellInfo:	
///			GSM cell info
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_GsmCellInfo
/// \sa SWI_NOTIFY_GsmCellInfo
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetGsmCellInfo(SWI_STRUCT_GsmCellInfo* pCellInfo, 
									U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the RSCP and Ec/Io measurements.
///			
/// Use of this function should be limited.  ::SWI_NOTIFY_RscpEcIo 
/// notification is generated when there is a change in the information.  
/// Use of notifications is preferred over direct polling.
///
/// This function is only supported on GSM devices.
///
/// \param	[OUT] pRscpEcIo:
///			RSCP and Ec/Io measurements.
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_RscpEcIo
/// \sa SWI_NOTIFY_RscpEcIo
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetRscpEcIo(SWI_STRUCT_RscpEcIo* pRscpEcIo, U32 timeout);

/*@}*/	// End of network management and status

///////////////////////////////////////////////////////////////////////////////
///
/// This function reports the temperature of the radio within the modem.  
/// 
/// The modem firmware monitors the radio temperature to protect electronics 
/// and prevent drift from specification.  SWI_NOTIFY_Temperature reports each
/// degree change in the radio temperature as well as when the modem has 
/// reached a danger point where automatic shutdown is imminent.  Use of 
/// notifications is preferred over polling.
///
/// If the shutdown temperature is reached, the modem will stop transmitting. 
/// The connection will appear to be terminated by the network.  After the 
/// modem has cooled, the connection may be restored.  No action by the host
/// application is required. 
///
/// This function is only supported on GSM devices.
///			
/// \param	[OUT] sTemperature:	
///			Temperature information
///
/// \param	[IN] timeout:
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_STRUCT_Temperature
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetTemperatureBer(SWI_STRUCT_Temperature *sTemperature, 
									   U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve data counter information.  Data counters
/// include total data transmitted and received since last clear, lifetime
/// data transmitted and received and the last clear date.
///
/// This function is only supported on GSM devices.
///			
/// \param	[OUT] pDataCounters:
///			Data counter information
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_STRUCT_DataCounters
/// \sa SwiClearDataCounters
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetDataCounters(SWI_STRUCT_DataCounters* pDataCounters, 
									 U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to clear data counters.  Clearable data counters
/// includes the total transmitted and received counters.  The lifetime data 
/// counters cannot be cleared.
///
/// This function is only supported on GSM devices.
///			
/// \param	[IN] pDataCounters:	
///			Data counter information
///
///	\param	[IN] timeout:		
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_STRUCT_DataCounters
/// \sa SwiGetDataCounters
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiClearDataCounters(SWI_STRUCT_DataCounters* pDataCounters, 
									   U32 timeout);


///////////////////////////////////////////////////////////////////////////////
///
/// This function allows the host to get the RAT mode of the device.
/// This function is only supported on GSM devices.
///			
/// \param	[OUT] sRat:	
///			RAT mode information. 
///
///	\param	[IN] timeout:		
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_STRUCT_Rat
/// \sa SwiSetRat
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetRat(SWI_STRUCT_Rat &sRat, 
									   U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function allows the host to set the RAT mode of the device.
/// This function is only supported on GSM devices.
///			
/// \param	[IN/OUT] sRat:	
///			RAT information. The structure size and RAT mode type must be 
///			supplied by the caller.  The action result is returned.
///
///	\param	[IN] timeout:		
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
/// 
/// \sa SWI_STRUCT_Rat
/// \sa SwiGetRat
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetRat(SWI_STRUCT_Rat &sRat, 
									   U32 timeout);


/** 
 * \defgroup GroupGsmProfiles Connection Profiles
 */
/*@{*/

///////////////////////////////////////////////////////////////////////////////
/// 
/// This function returns a summary of the status of all account profiles, 
/// and identifies which one is the default profile for auto connection.
/// 
/// Use this function with AC7xx and MP7XX devices only  For 3G and newer
/// devices, use ::SwiGetGsmProfileSummary.
/// 
/// The summary reports the status of each profile along with its context 
/// number.  The summary structure reports two profile context identities: 
/// one for the default profile used for automatic activation, and another to 
/// identify the current profile that is actively connected to the network 
/// (activated). If the modem is not currently connected, the current profile 
/// context is reported as zero.		
///			
/// \param	[OUT] pProfileSummary:	
///			Profile summary information.
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_ProfileSummary
/// \sa SwiGetGsmProfileSummary
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetProfileSummary(
					SWI_STRUCT_ProfileSummary* pProfileSummary, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
/// 
/// These function returns a summary of the status of all account profiles, 
/// and identifies which one is the default profile for auto connection.
/// 
/// Use this function with 3G and newer devices.  ::SwiGetProfileSummary should
/// be used with older devices.
/// 
/// The summary reports the status of each profile along with its context 
/// number.  The summary structure reports two profile context identities: 
/// one for the default profile used for automatic activation, and another to 
/// identify the current profile that is actively connected to the network 
/// (activated). If the modem is not currently connected, the current profile 
/// context is reported as zero.
///			
/// \param	[OUT] pProfileSummary:
///			Profile summary information
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
///	\sa SWI_STRUCT_GsmProfileSummary
/// \sa SwiGetProfileSummary
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetGsmProfileSummary(
					SWI_STRUCT_GsmProfileSummary* pProfileSummary, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the details of a connection profile.
/// 
/// This function should only be used with AC7xx and MP7XX devices.  For 3G
/// and newer devices, use the following set of profile APIs:
///		- ::SwiGetGsmProfileBasic
///		- ::SwiGetGsmProfileQos
///		- ::SwiGetGsmProfileDns
///		- ::SwiGetGsmProfileTft
/// 
/// Calling this function on profile that is not present (deleted) returns
/// default profile settings.  
///
///	\param	[OUT] pProfile:	
///			Profile information
///
///	\param	[IN] nProfileID:	
///			Profile ID to retrieve
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
///	\sa SWI_STRUCT_Profile
/// \sa SwiGetGsmProfileBasic
///	\sa SwiGetGsmProfileQos
///	\sa SwiGetGsmProfileDns
///	\sa SwiGetGsmProfileTft
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetProfile(SWI_STRUCT_Profile* pProfile, 
								const U32 nProfileID, 
								U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function retrieves the basic details of a connection profile.
///
/// This function is used with 3G and newer devices.  For older devices,
/// use ::SwiGetProfile.
/// 
/// Calling this function on profile that is not present (deleted) returns
/// default profile settings.
/// 
/// ::SWI_NOTIFY_GsmProfileChange can be used to monitor for changes made to
/// profile information.
///
/// \param	[IN/OUT] pProfile:	
///			Basic profile information.  Caller must specify the caller ID.
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed by the modem.  See nResult defined 
///			in SWI_STRUCT_GsmProfileBasic for the status of the request.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_GsmProfileBasic
/// \sa SWI_NOTIFY_GsmProfileChange
///	\sa SwiGetGsmProfileQos
///	\sa SwiGetGsmProfileDns
///	\sa SwiGetGsmProfileTft
/// \sa SwiSetGsmProfileBasic
///	\sa SwiSetGsmProfileQos
///	\sa SwiSetGsmProfileDns
///	\sa SwiSetGsmProfileTft
///	\sa SWI_STRUCT_Profile
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetGsmProfileBasic(SWI_STRUCT_GsmProfileBasic* pProfile, 
										U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function retrieves the QoS details of a connection profile.
///
/// This function is used with 3G and newer devices.  For older devices,
/// use ::SwiGetProfile.
/// 
/// Calling this function on profile that is not present (deleted) returns
/// default profile settings.
/// 
/// ::SWI_NOTIFY_GsmProfileChange can be used to monitor for changes made to
/// profile information.
///
/// \param	[IN/OUT] pProfile:	
///			QoS profile information.  Caller must specify the profile ID.
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_GsmProfileQos
/// \sa SWI_NOTIFY_GsmProfileChange
/// \sa SwiGetGsmProfileBasic
///	\sa SwiGetGsmProfileDns
///	\sa SwiGetGsmProfileTft
/// \sa SwiSetGsmProfileBasic
///	\sa SwiSetGsmProfileQos
///	\sa SwiSetGsmProfileDns
///	\sa SwiSetGsmProfileTft
///	\sa SWI_STRUCT_Profile
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetGsmProfileQos(SWI_STRUCT_GsmProfileQos* pProfile, 
									  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function retrieves the DNS details of a connection profile.
///
/// This function is used with 3G and newer devices.  For older devices,
/// use ::SwiGetProfile.
/// 
/// Calling this function on profile that is not present (deleted) returns
/// default profile settings.
/// 
/// ::SWI_NOTIFY_GsmProfileChange can be used to monitor for changes made to
/// profile information.
///
/// \param	[IN/OUT] pProfile:	
///			DNS profile information.  Caller must specify the profile ID.
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_GsmProfileDns
/// \sa SWI_NOTIFY_GsmProfileChange
/// \sa SwiGetGsmProfileBasic
///	\sa SwiGetGsmProfileQos
///	\sa SwiGetGsmProfileTft
/// \sa SwiSetGsmProfileBasic
///	\sa SwiSetGsmProfileQos
///	\sa SwiSetGsmProfileDns
///	\sa SwiSetGsmProfileTft
///	\sa SWI_STRUCT_Profile
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetGsmProfileDns(SWI_STRUCT_GsmProfileDns* pProfile, 
									  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function retrieves the TFT details of a connection profile.
///
/// This function is used with 3G and newer devices.  Older devices do not
/// support TFT configurations.
/// 
/// Calling this function on profile that is not present (deleted) returns
/// default profile settings.
/// 
/// ::SWI_NOTIFY_GsmProfileChange can be used to monitor for changes made to
/// profile information.
///
/// \param	[IN/OUT] pProfile:	
///			TFT profile information.  Caller must specify the profile ID.
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_GsmProfileTft
/// \sa SWI_NOTIFY_GsmProfileChange
/// \sa SwiGetGsmProfileBasic
///	\sa SwiGetGsmProfileDns
///	\sa SwiGetGsmProfileQos
/// \sa SwiSetGsmProfileBasic
///	\sa SwiSetGsmProfileQos
///	\sa SwiSetGsmProfileDns
///	\sa SwiSetGsmProfileTft
///	\sa SWI_STRUCT_Profile
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetGsmProfileTft(SWI_STRUCT_GsmProfileTft* pProfile, 
									  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function stores the user connection information in a profile slot, 
/// making it available for connection.
///
/// This function should only be used with AC7xx and MP7XX devices.  For 3G
/// and newer devices, use the following set of profile APIs:
///		- ::SwiSetGsmProfileBasic
///		- ::SwiSetGsmProfileQos
///		- ::SwiSetGsmProfileDns
///		- ::SwiSetGsmProfileTft
/// 
/// For a profile with bAutomaticIP set to true, the API will force the setting
/// of dwPDPAddress to zeros. Automatic IP setting takes precedence over
/// a user-assigned IP.
///			
/// \param	[IN] pProfile:	
///			Profile information to be written to modem.
///
///	\param	[IN] nProfileID:	
///			Profile ID to be updated
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed.
/// 
/// \return SWI_RCODE_FAILED:
///			The modem will verify the validity of the data in the profile 
///			structure.   If it fails to validate, the function will return 
///			::SWI_RCODE_FAILED.  You must use the validation process provided in 
///			the sample code to ensure the profile data can be written.  If the
///			 profile is active when you attempt to write a new setting, the 
///			function will also return ::SWI_RCODE_FAILED.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
///	\sa SWI_STRUCT_Profile
/// \sa SWI_NOTIFY_GsmProfileChange
/// \sa SwiSetGsmProfileBasic
///	\sa SwiSetGsmProfileQos
///	\sa SwiSetGsmProfileDns
///	\sa SwiSetGsmProfileTft
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetProfile(const SWI_STRUCT_Profile* pProfile, 
								const U32 nProfileID, 
								U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function stores the basic user account information in a profile slot, 
/// making it available for connection.
///			
/// This function is used with 3G and newer devices.  For older devices,
/// use ::SwiSetProfile.
///
/// \param	[IN] pProfile:	
///			Basic profile information to be updated on the modem.  The profile 
///			ID and size of the structure must be provided by the caller.
///
/// \param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed.
/// 
/// \return ::SWI_RCODE_FAILED:
///			The modem will verify the validity of the data in the profile 
///			structure.   If it fails to validate, the function will return 
///			::SWI_RCODE_FAILED.  You must use the validation process provided in 
///			the sample code to ensure the profile data can be written.  If the
///			profile is active when you attempt to write a new setting, the 
///			function will also return ::SWI_RCODE_FAILED.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
///	\sa SWI_STRUCT_GsmProfileBasic
/// \sa SWI_NOTIFY_GsmProfileChange
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetGsmProfileBasic(SWI_STRUCT_GsmProfileBasic pProfile, 
										U32 timeout);

///////////////////////////////////////////////////////////////////////////////
/// 
/// This function stores the QoS user account information in a profile slot.
///			
/// This function is used with 3G and newer devices.  For older devices,
/// use ::SwiSetProfile.
///
/// \param	[IN] pProfile:	
///			QoS profile information to be updated on the modem.  The profile 
///			ID and size of the structure must be provided by the caller.
///
/// \param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed.
/// 
/// \return ::SWI_RCODE_FAILED:
///			The modem will verify the validity of the data in the profile 
///			structure.   If it fails to validate, the function will return 
///			::SWI_RCODE_FAILED.  You must use the validation process provided in 
///			the sample code to ensure the profile data can be written.  If the
///			profile is active when you attempt to write a new setting, the 
///			function will also return ::SWI_RCODE_FAILED.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
///	\sa SWI_STRUCT_GsmProfileQos
/// \sa SWI_NOTIFY_GsmProfileChange
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetGsmProfileQos(SWI_STRUCT_GsmProfileQos pProfile, 
									  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function stores the DNS user account information in a profile slot.
///			
/// This function is used with 3G and newer devices.  For older devices,
/// use ::SwiSetProfile.
///
/// \param	[IN] pProfile:	
///			DNS profile information to be updated on the modem.  The profile 
///			ID and size of the structure must be provided by the caller.
///
/// \param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed.
/// 
/// \return ::SWI_RCODE_FAILED:
///			The modem will verify the validity of the data in the profile 
///			structure.   If it fails to validate, the function will return 
///			::SWI_RCODE_FAILED.  You must use the validation process provided in 
///			the sample code to ensure the profile data can be written.  If the
///			profile is active when you attempt to write a new setting, the 
///			function will also return ::SWI_RCODE_FAILED.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
///	\sa SWI_STRUCT_GsmProfileDns
/// \sa SWI_NOTIFY_GsmProfileChange
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetGsmProfileDns(SWI_STRUCT_GsmProfileDns pProfile, 
									  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function stores the TFT user account information in a profile slot.
///			
/// This function is used with 3G and newer devices.  Older devices do not 
/// support TFT configurations.
///
/// \param	[IN] pProfile:	
///			TFT profile information to be updated on the modem.  The profile 
///			ID and size of the structure must be provided by the caller.
///
/// \param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed.
/// 
/// \return ::SWI_RCODE_FAILED:
///			The modem will verify the validity of the data in the profile 
///			structure.   If it fails to validate, the function will return 
///			::SWI_RCODE_FAILED.  You must use the validation process provided in 
///			the sample code to ensure the profile data can be written.  If the
///			profile is active when you attempt to write a new setting, the 
///			function will also return ::SWI_RCODE_FAILED.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
///	\sa SWI_STRUCT_GsmProfileTft
/// \sa SWI_NOTIFY_GsmProfileChange
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetGsmProfileTft(SWI_STRUCT_GsmProfileTft pProfile, 
									  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function will erase the account information from a profile and 
/// restore to factory defaults.  The profile will then report a status of 
/// "deleted".  
///			
/// \param	[IN] nProfileID:	
///			Profile ID to be erased.  Profile ID ranges from 1-16 for 3G and
///			newer devices and 1-3 for older (AC7xx and MP7xx) devices. 
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed.
/// 
/// \return ::SWI_RCODE_FAILED:
///			If the profile is active when you attempt to write a new setting, 
///			the function will return ::SWI_RCODE_FAILED.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_NOTIFY_GsmProfileChange
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiEraseProfile(const U32 nProfileID, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function sets which profile is to be used for possible automatic 
/// connection.  If the profile that is set to be the default has the auto 
/// connection flag set to true, then that profile will be used to connect to 
/// the network automatically when the modem is started or reset.
/// 
/// The modem does not verify that the profile contains a valid (non-blank) 
/// account. You can set the default to a "deleted" profile; the autoconnect
/// flag will be false so this is equivalent to disabling autoconnection.
///			
/// \param	[IN] nProfileID:	
///			Profile ID to be made the default.  Profile ID ranges from 1-16 for
///			3G and newer devices and 1-3 for older (AC7xx and MP7xx) devices. 
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed.
///
///	\return	See ::SWI_RCODE for other error return codes.
/// 
/// \sa SwiGetGsmProfileSummary
/// \sa SwiGetProfileSummary
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetDefaultProfile(const U32 nProfileID, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function initiates or destroys a packet session.
///			
/// \param	[IN] nProfileID:	
///			Profile ID to acted on.  Profile ID ranges from 1-16 for
///			3G and newer devices and 1-3 for older (AC7xx and MP7xx) devices. 
///
///	\param	[IN] Activate:	
///			True if the profile should be activated.  False if the profile 
///			should be deactivated.
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///			The request has been processed.  A ::SWI_NOTIFY_PktSessionStatus 
///			notification will indicate the result of the request.
/// 
/// \return ::SWI_RCODE_REQUEST_REJECTED:
///			Activation requests MAY be rejected if FDN is enabled.  This 
///			behaviour is customizable by the carrier.  ::SwiGetLastError would
///			return "FDN Mismatch".
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_NOTIFY_PktSessionStatus
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiActivateProfile(const U32 nProfileID, 
									 bool Activate, 
									 U32 timeout);

/*@}*/ // End of Profile group

/**
 * Call Management and Voice Features
 */
/*@{*/	

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to initiate an outgoing voice call.  A request
/// containing the phone number is sent to the modem.  The modem will
/// respond to the request indicating that the request is being processed.
/// The SWI_NOTIFY_CallProgress and SWI_NOTIFY_CallStatus notifications will 
/// reflect the status of the created call.  
///
/// A wait period is required between calls of this function.  If the
/// function is called twice without a sufficient wait between the 
/// first and second call, it turns a "FAILED" return code.  The
/// duration that must elapse between calls is network dependent
/// and the recommendation is to experiment with different
/// durations before deciding on a wait period.  
///
/// \param [IN] pCall:	
///        Information needed to create the call
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_CALL_Create
/// \sa SWI_NOTIFY_CallProgress
/// \sa SWI_NOTIFY_CallStatus
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetCallOriginate(const SWI_STRUCT_CALL_Create* pCall, 
									  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This API has been replaced by SwiSetCallControlUMTS.  Do not use this API.
///
/// This function is used to answer calls and manage multiple calls. Use this 
/// function to: answer an incoming call, put a call on hold, activate a call 
/// (take it off hold), link calls to create a multi-party call, swap an 
/// active call and on hold call and disconnect a call. 
///
/// A request is sent to the modem indicating the call id and the action 
/// to take.  The modem will respond to the request indicating that the 
/// request is being processed.  The SWI_NOTIFY_CallProgress and 
/// SWI_NOTIFY_CallStatus notifications will reflect the status of the current
/// calls.  
///
/// The caller must specify the amount of time to wait for the modem
/// to respond to the request. 
///
/// \param [IN] pCall:	
///        Information needed to control an call in progress
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SwiSetCallControlExp
/// \sa SWI_STRUCT_CALL_Control
/// \sa SWI_NOTIFY_CallProgress
/// \sa SWI_NOTIFY_CallStatus
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetCallControl(const SWI_STRUCT_CALL_Control* pCall, 
									U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This API has been replaced by SwiSetCallControlUMTS.  Do not use this API.
///
/// This function is used to answer calls and manage multiple calls. Use this 
/// function to: answer an incoming call, put a call on hold, activate a call 
/// (take it off hold), link calls to create a multi-party call, swap an 
/// active call and on hold call and disconnect a call. 
///
/// A request is sent to the modem indicating the call id and the action 
/// to take.  The modem will respond to the request indicating that the 
/// request is being processed.  The SWI_NOTIFY_CallProgress and 
/// SWI_NOTIFY_CallStatus notifications will reflect the status of the current
/// calls.  
///
/// \param [IN] pCall:	
///        Information needed to control an call in progress
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SwiSetCallControlExp
/// \sa SWI_STRUCT_CALL_Control
/// \sa SWI_NOTIFY_CallProgress
/// \sa SWI_NOTIFY_CallStatus
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetCallControlExp(const SWI_STRUCT_CALL_Control* pCall, 
									   U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to answer calls and manage multiple calls. Use this 
/// function to: answer an incoming call, put a call on hold, activate a call 
/// (take it off hold), link calls to create a multi-party call, swap an 
/// active call and on hold call and disconnect a call. 
///
/// A request is sent to the modem indicating the call id and the action 
/// to take.  The modem will respond to the request indicating that the 
/// request is being processed.  The SWI_NOTIFY_CallProgress and 
/// SWI_NOTIFY_CallStatus notifications will reflect the status of the current
/// calls.   
///
/// This API replaces SwiSetCallControlExp.
///
/// \param [IN] pCall:	
///        Information needed to control an call in progress
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_CALL_UMTS_Control
/// \sa SWI_STRUCT_CALL_Control
/// \sa SWI_NOTIFY_CallProgress
/// \sa SWI_NOTIFY_CallStatus
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetCallControlUMTS(
					const SWI_STRUCT_CALL_UMTS_Control* pCall, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to play a continuous DTMF tone over the
/// earpiece and over-the-air.  This function must be called to start
/// the tone and then called again to stop the tone.
///
/// For earpiece feedback, the duration of the tone is limited to an
/// absolute maximum.  However, the over-the-air tones may play
/// continuously for the duration of the voice call until the stop
/// request is sent.  Some carriers limit the maximum duration of tones
/// sent over-the-air.
///
/// \param [IN] pDtmf:	
///        Information about the DTMF tone to be sent
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SwiSetContDtmf
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetContDtmf(SWI_STRUCT_ContDtmf *pDtmf, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to send over-dial numbers during calls. This sends 
/// the digits as well as setting the duration of the DTMF tone and the
/// duration of the interval between tones. It also enables/disables ear piece 
/// feedback (which determines whether the tone is audible).
///
/// Over-dial digits are numbers that are dialed after a circuit-switched 
/// call has been established to communicate with a voice messaging system 
/// or a PBX (for example, to enter a credit card number).  If your 
/// application has a phone book feature, entries in the phone book may 
/// contain over-dial digits separated from the main calling number
/// by the "DTMF Control Digit Separator" (a comma). For example, 
/// there might be a phone book entry, '6045551234,201,8'. This includes
/// a component, ',201,8' to be over-dialed after the call is established.  
/// The first comma separates the over-dial digits from the main number.
/// All commas, including the first one, generate a three-second pause
/// between the dialed numbers.  In this example, there would be a
/// three-second pause before '201' and between '201 and '8'.  You would
/// use the function SwiSetCallOriginate to dial the phone number 
/// ('6045551234'). Once the call is established, use SwiSetDTMFSend 
/// to send the ',201,8'. The maximum number of digits that can be sent
/// with this function is 20.
/// 
/// \param [IN] pDTMFSend:	
///        Information about the DTMF tones to be sent
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_DTMFSend
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetDTMFSend(SWI_STRUCT_DTMFSend *pDTMFSend, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function allows the application to store DTMF duration and feedback
/// settings on the device.  The intention is for the application to have a 
/// user-defined tone configuration associated with a specific device
/// rather than tied to a host).  
///
/// The device does not make use of the stored DTMF duration setting, it 
/// simply allows for the application to read and write these settings.
/// The idea is that the host application will use these setting when
/// calling SwiSetDTMFSend to send over-dial digits over the air, rather
/// than using durations stored on the host or hard-coded in the host
/// application.
///
/// Every parameter in the data structure must be valid and none may 
/// be omitted.  
///
/// The earpiece feedback setting stored by this function 
/// is used by the SwiSetContDtmf function.
///
/// \param [IN] pToneLength:	
///        Information about the DTMF tones to be stored on the device
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_NVToneStore
/// \sa SwiGetNVToneStore
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetNVToneStore(SWI_STRUCT_NVToneStore *pToneLength, 
									U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function allows the application to retrieve stored DTMF duration 
/// and feedback settings on the device.  The intention is for the application 
/// to have a user-defined tone configuration associated with a specific device
/// rather than tied to a host).  
///
/// \param [OUT] pToneLength:	
///        Information about the DTMF tones store on the device
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_NVToneStore
/// \sa SwiSetNVToneStore
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetNVToneStore(SWI_STRUCT_NVToneStore *pToneLength, 
									U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to set the speaker volume.  The speaker volume 
/// is stored on the modem.
///
/// The value used in this function is the percentage of full volume. 
/// This is stored in NVRAM.  The host application may present a few 
/// volume levels that are mapped to specific percentage levels. For 
/// example, the application might have six volume levels where: 
/// 1 = 17%, 2 = 33%, 3 = 50%, 4 = 66%, 5 = 83%, and 6 = 100%.
///	
/// \param [IN] sSpeakerVolume:	
///        Speaker volume
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_GSM_SpeakerVolume
/// \sa SwiGetGsmSpeakerVolume
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetGsmSpeakerVolume(
					SWI_STRUCT_GSM_SpeakerVolume *sSpeakerVolume, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the speaker volume.  The speaker volume
/// setting is stored on the modem.
///
/// The value returned is the percentage of full volume. This 
/// function should be used every time the host application is started 
/// to restore the previous setting.
///
/// \param [OUT] sSpeakerVolume:	
///        Speaker volume
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_GSM_SpeakerVolume
/// \sa SwiSetGsmSpeakerVolume
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetGsmSpeakerVolume(
					SWI_STRUCT_GSM_SpeakerVolume *sSpeakerVolume, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to mute the speaker.
/// The speaker mute setting is stored on the modem.
///
/// This function does not impact speaker volume but only enables and 
/// disables muting. Settings made with this function are lost when the
/// modem resets. The setting is not lost when switching between calls. 
/// The application should ensure that the speaker is on when the user
/// switches between calls.
///
/// \param [IN] pSpeakerMute:	
///        Speaker mute setting
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_GSM_SpeakerMute
/// \sa SwiGetSpeakerMute
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetSpeakerMute(SWI_STRUCT_GSM_SpeakerMute *pSpeakerMute,
									U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the speaker mute setting.  The 
/// speaker mute setting is stored on the modem.
///
/// Use this function every time the host application is started to 
/// determine whether the speaker mute is enabled. (In this way, the 
/// speaker setting is attached to the modem, rather than the host.)
///
/// \param [OUT] pSpeakerMute:	
///        Speaker mute setting
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_GSM_SpeakerMute
/// \sa SwiSetSpeakerMute
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetSpeakerMute(SWI_STRUCT_GSM_SpeakerMute *pSpeakerMute, 
									U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to mute or un-mute the microphone.  
///
/// This function does not impact microphone volume but only enables and 
/// disables muting.  
/// 
/// When in a multi-party call, the microphone setting is persistent when 
/// switching from one call to another.  For example, you have two active 
/// calls, A and B.  You mute call A.  When you disconnect call A or transfer 
/// to call B, the microphone setting is maintained and the still muted.  
/// However, the mute setting is automatically disabled when all active calls 
/// are disconnected. 
/// 
/// Microphone mute settings are not persistent across modem resets.  The
/// microphone is un-muted by default. 
///
/// \param [IN] pMicMute:	
///        Microphone mute setting
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_MicMute
/// \sa SwiGetMicMute
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetMicMute(SWI_STRUCT_MicMute *pMicMute, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the microphone mute setting.
/// The microphone mute setting is stored on the modem.
///
/// Use this function every time the host application is started to 
/// determine whether the microphone mute is enabled. (In this way, 
/// the microphone setting is attached to the modem, rather than the
/// host.)
///
/// \param [OUT] pMicMute:	
///        Microphone mute setting
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_MicMute
/// \sa SwiSetMicMute
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMicMute(SWI_STRUCT_MicMute *pMicMute, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve voice mail waiting status.  This indicates
/// if there is new voice mail.
///
/// Use this function to get the initial status (whether or not there are 
/// voice messages) when launching the application.  Following this initial 
/// check, the SWI_NOTIFY_VoiceMessage notification informs the application 
/// as new messages arrive.  A field in the data structure (VoiceMailWaiting-
/// Feature) is intended to report whether voice messaging is a provisioned 
/// service, but this is a network dependent feature. The application should 
/// NOT use this field.
///
/// This function should not be called until the application receives
/// the SWI_NOTIFY_SmsReady notification. 
///
/// \param [OUT] pVoiceMessage:	
///        Voice mail waiting status
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_VoiceMessage
/// \sa SWI_NOTIFY_VoiceMessage
/// \sa SWI_NOTIFY_SmsReady 
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetVoiceMessage(SWI_STRUCT_VoiceMessage *pVoiceMessage, 
									 U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to acknowledge missed calls.  This causes the missed
/// count to be reset.
///
/// \param [OUT] pMissedCall:	
///        Missed calls
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_MissedCall
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiAcknowledgeMissedCall(SWI_STRUCT_MissedCall *pMissedCall, 
										   U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to modify the caller line identity restriction (CLIR)
/// setting on the modem.  A request is sent to the modem specifying the 
/// a CLIR setting.  The modem will respond to the request indicating that the
/// setting has been changed.      
///
/// \param [IN] pCLIR:	
///        CLIR setting
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_CLIR_Setting
/// \sa SwiGetCLIRSetting
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetCLIRSetting(const SWI_STRUCT_CLIR_Setting *pCLIR, 
									U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to fetch the caller line identity restriction (CLIR)
/// setting from the modem.  A request is sent to the modem.  The modem 
/// will respond with the current CLIR setting.  
///   
///
/// \param [OUT] pCLIR:	
///        Current CLIR setting
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_CLIR_Setting
/// \sa SwiSetCLIRSetting
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetCLIRSetting(SWI_STRUCT_CLIR_Setting *pCLIR, 
									U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to respond to an incoming call with the User 
/// Determined User Busy (UDUB)feature.  UDUB will automatically send
/// the incoming call to voicemail or return a busy signal.
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetUserdefinedUserBusy(U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to get TTY settings from the modem 
///			
/// \param	[OUT] sTTY:			
///			TTY settings returned from the modem
///
/// \param	[IN] timeout:
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_TTYControl
/// \sa SwiSetTTY
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetTTY(SWI_STRUCT_TTYControl &sTTY, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to set TTY settings to the modem.
///			
/// \param	[OUT] sTTY:
///			TTY Settings
///
/// \param	[IN] timeout:
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_TTYControl
/// \sa SwiGetTTY
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetTTY(SWI_STRUCT_TTYControl &sTTY, U32 timeout);

/*@}*/ // End of Call and Voice group

/** 
 * \defgroup GroupGsmPhonebook Phonebook
 */
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to determine what phonebooks are available.
///
/// This function should only be called after a ::SWI_NOTIFY_PhonebookReady 
/// notification has been received indicating phonebooks are ready.
///			
/// \param	[OUT] pPhonebook:
///			Phonebook availability status
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_PHONEBK_Available
/// \sa SWI_NOTIFY_PhonebookReady
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetPhonebookAvailable(
					SWI_STRUCT_PHONEBK_Available* pPhonebook, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to query the number of remaining free entries and the
/// size of all of the phonebooks on the SIM.
///
/// This function should not be called until the ::SWI_NOTIFY_PhonebookReady
/// has been received indicating phonebooks are ready. 
///
/// \param	[OUT] pPhonebook:
///			Phonebook availability status
///
/// \param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_PHONEBK_Size
/// \sa SWI_NOTIFY_PhonebookReady
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetPhonebookSize(SWI_STRUCT_PHONEBK_Size*	pPhonebook, 
									  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve a phonebook entry.
///
/// This function should not be called until the ::SWI_NOTIFY_PhonebookReady
/// has been received indicating phonebooks are ready. 
/// 
/// There are several different phonebooks on the modem and SIM.  This function
/// can request either the first or next entry be read from a particular 
/// phonebook.  To get the entire contents of a phonebook call this function 
/// requesting the first entry and then repeatedly request the next entry for 
/// all subsequent function calls.    
///			
/// \param	[IN/OUT] pPhonebook:
///			Phonebook entry information.  The structure size, phonebook type,
///			and bReadFromStart flag must be populated by the caller.  The other
///			fields are returned from the modem.  Note that you can not read
///			a phonebook entry directly by specifying the entry ID.
///
/// \param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///			See pPhonebook->eResultCode for result of the operation.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_PHONEBK_Entry
/// \sa SWI_NOTIFY_PhonebookReady
/// \sa SwiAddPhonebookEntry
/// \sa SwiEditPhonebookEntry
/// \sa SwiDeletePhonebookEntry
/// \sa SwiDeletePhonebookLastNum
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetPhonebookEntry(SWI_STRUCT_PHONEBK_Entry* pPhonebook,
									   U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// Use this function to add a phonebook entry.
///
/// This function should not be called until the ::SWI_NOTIFY_PhonebookReady
/// has been received indicating phonebooks are ready. 
/// 
/// \param	[IN/OUT] pPhonebook:
///			Phonebook entry to be added.  The structure size, phonebook type,
///			name, and number must be supplied by the caller.  The phonebook 
///			entry ID is returned in the same structure and should be stored
///			to be used to for modify or deleting the entry later.  
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///			See pPhonebook->eResultCode for result of the operation.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_PHONEBK_Entry
/// \sa SWI_NOTIFY_PhonebookReady
/// \sa SwiGetPhonebookEntry
/// \sa SwiEditPhonebookEntry
/// \sa SwiDeletePhonebookEntry
/// \sa SwiDeletePhonebookLastNum
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiAddPhonebookEntry(SWI_STRUCT_PHONEBK_Entry* pPhonebook,
									   U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to modify an existing phonebook entry.
/// 
/// This function should not be called until the ::SWI_NOTIFY_PhonebookReady
/// has been received indicating phonebooks are ready.  
/// 
/// The phonebook entry must be known ahead of time (either returned from 
/// ::SwiAddPhonebookEntry or ::SwiGetPhonebookEntry).
///
/// \param	[IN/OUT] pPhonebook:
///			Replacement phonebook entry.  The structure size, phonebook entry,
///			phonebook type, name, and number must be supplied by the caller.
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///			See pPhonebook->eResultCode for result of the operation.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_PHONEBK_Entry
/// \sa SWI_NOTIFY_PhonebookReady
/// \sa SwiGetPhonebookEntry
/// \sa SwiAddPhonebookEntry
/// \sa SwiDeletePhonebookEntry
/// \sa SwiDeletePhonebookLastNum
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiEditPhonebookEntry(SWI_STRUCT_PHONEBK_Entry* pPonebook, 
										U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// Use this function to delete a phonebook entry.
///
/// This function should not be called until the ::SWI_NOTIFY_PhonebookReady
/// has been received indicating phonebooks are ready. 
///			
/// \param	[IN/OUT] pPhonebook:
///			Phonebook entry to be deleted.  The structure size, phonebook entry,
///			and phonebook type must be supplied by the caller.
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///			See pPhonebook->eResultCode for result of the operation.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_PHONEBK_DeleteEntry
/// \sa SWI_NOTIFY_PhonebookReady
/// \sa SwiGetPhonebookEntry
/// \sa SwiAddPhonebookEntry
/// \sa SwiEditPhonebookEntry
/// \sa SwiDeletePhonebookLastNum
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiDeletePhonebookEntry(
					SWI_STRUCT_PHONEBK_DeleteEntry* pPhonebook, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// Use this function to clear the entire last numbers dialed, last numbers 
/// missed or last numbers received phonebooks.  
/// 
/// This function should not be called until the ::SWI_NOTIFY_PhonebookReady
/// has been received indicating phonebooks are ready. 
///			
/// \param	[IN] ePhonebookType: 
///			Phonebook to be cleared
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_TYPE_Phonebook
/// \sa SWI_NOTIFY_PhonebookReady
/// \sa SwiGetPhonebookEntry
/// \sa SwiAddPhonebookEntry
/// \sa SwiEditPhonebookEntry
/// \sa SwiDeletePhonebookEntry
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiDeletePhonebookLastNum(
					const SWI_TYPE_Phonebook ePhonebookType, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to request the fixed number dialing (FDN) mode
/// from the modem.  
///			
/// \param	[OUT] pFdnEnabled:	
///			True if FDN is enabled, false otherwise. 
///
/// \param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SwiSetFdnMode
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetFdnMode(bool* pFdnEnabled, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to set the fixed number dialing (FDN) mode
/// on the modem.
/// 
/// Before calling this function, CHV2 must be verified.  CHV2 is prompted for
/// by calling ::SwiChv2StatusKick.  
///			
/// \param	[IN/OUT] pFdn:	
///			Set bEnabled to true to enable FDN, false otherwise.  eResultCode
///			contains the result of the request.
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///			See eResultCode within the SWI_STRUCT_FdnMode structure for
///			the result of the operation.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_FdnMode
/// \sa SwiChv2StatusKick
/// \sa SwiGetFdnMode
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetFdnMode(SWI_STRUCT_FdnMode* pFdn, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to get CHV2 status from the modem.  
///			
/// SIM API functions can not be called until a ::SWI_NOTIFY_SimStatusExp
/// notification is received.  This indicates that the SIM is ready to 
/// process user requests.
/// 
/// The kick type determines if the user is prompted to enter the CHV2.  For
/// example, if the card is kicked for CHV2 verify, then 
/// ::SWI_NOTIFY_SimStatusExp will contain a user prompt to enter CHV2.  If the
/// card is kicked for CHV2 change, ::SWI_NOTIFY_SimStatusExp will not contain
/// user prompts.
///
/// \param	[IN] eKickType:
///			CHV2 kick type
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed.  The ::SWI_NOTIFY_SimStatusExp 
///			notification indicates the result of the operation and any
///			additional actions required by the user. 
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_TYPE_SIM_Chv2KickType
/// \sa SWI_NOTIFY_SimStatusExp
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiChv2StatusKick(SWI_TYPE_SIM_Chv2KickType eKickType, 
									U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// The modem contains a list of emergency numbers.  This function is used
/// to fetch the emergency numbers one at a time.  Set the first flag when 
/// calling this function to retrieve the first entry in the list.  To 
/// retrieve the entire list call this function repeatedly.  
///
/// This function sends a request to the modem.  The modem's response will
/// contain an emergency number string and indicate if this is the last
/// number in the list.    
///
/// \param [IN/OUT] pEmergencyNumber:	
///        Phonebook entry
///
/// \param [IN] bfirst:	
///        First emergency number flag (this flag should only be 
///        set the first time this function is called)
///
/// \param [IN] timeout:	
///        Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK: 
///         The request is being processed.
///
/// \return SWI_RCODE_REQUEST_TIMEOUT
///         The request has timed out
///
/// \return See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_Emergency_Number
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetEmergencyEntry(
					SWI_STRUCT_Emergency_Number *pEmergencyNumber, 
					bool bFirst, 
					U32 timeout);
									   
/*@}*/ // End of Phonebook group

/**
 * \defgroup GroupGsmSim SIM
 */
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the IMSI from the SIM.  
/// 
/// The IMSI is comprised of three elements: the MSIN, the MCC and the MNC. 
///			
/// \param	[OUT] szMSIN:	
///			MSIN (NULL terminated) 
///
///	\param	[IN] sizeBuffer:	
///			The size of the buffer provided for the MSIN.
///
/// \param	[OUT] pMCC:		
///			Mobile country code
///
///	\param	[OUT] pMNC:		
///			Mobile network code
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds.
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return See ::SWI_RCODE for other error return codes.
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetGsmIMSI(LPTSTR szMSIN, 
								U32 sizeBuffer, 
								U32 *pMCC, 
								U32 *pMNC, 
								U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to enter a SIM requested code.
/// 
/// SIM API functions can not be called until a ::SWI_NOTIFY_SimStatusExp
/// notification is received.  This indicates that the SIM is ready to 
/// process user requests.
///
/// The SIM can request the user to enter any one of the following four codes:  
/// CHV1, CHV2, unblocking CHV1 and unblocking CHV2.  The SIM uses this to 
/// verify the identify of the user.  This function allows the caller to pass 
/// the user entered code to the SIM on the modem.  A request containing the 
/// code is sent to the modem.  The modem will respond to the request to 
/// indicate that the code is being verified by the SIM.  The result of the SIM
/// verification will be reflected in the ::SWI_NOTIFY_SimStatusExp notification.    
///			
/// If three failures in entering a correct CHV1 or CHV2 occur, this 
/// notification shows that the SIM has become blocked (CHV1) or the CHV2
/// features have become blocked.
///
/// GSM standards designate 10 as the number of permitted attempts at correctly
/// entering PUK codes. This number is SIM dependent and carriers do not 
/// necessarily adhere to this standard.  If 10 failures in entering the PUK 
/// occur, this notification shows the SIM has become permanently blocked or 
/// the CHV2 features have become permanently blocked.
///
/// \param	[IN] pSim:
///			SIM requested code.
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed.  The ::SWI_NOTIFY_SimStatusExp 
///			notification indicates whether the designated code matched.  It 
///			also shows the number of attempts at entering the code correctly.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_SIM_Verify
/// \sa SWI_NOTIFY_SimStatusExp
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetSimVerify(const SWI_STRUCT_SIM_Verify* pSim, 
								  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to enable or disable CHV1.  
/// 
/// SIM API functions can not be called until a ::SWI_NOTIFY_SimStatusExp
/// notification is received.  This indicates that the SIM is ready to 
/// process user requests.
///			
/// \param	[IN] pSim:
///			SIM CHV1 lock information.  The caller must provide the password
///			required to enable/disable CHV1.
///
/// \param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed.  The ::SWI_NOTIFY_SimStatusExp 
///			notification indicates the result of the operation. 
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_SIM_EnableLock
/// \sa SWI_NOTIFY_SimStatusExp
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetSimLock(const SWI_STRUCT_SIM_EnableLock* pSim, 
								U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to determine whether CHV1 is enabled. 
///			
/// SIM API functions can not be called until a ::SWI_NOTIFY_SimStatusExp
/// notification is received.  This indicates that the SIM is ready to 
/// process user requests.
///
/// \param	[OUT] pSim:		
///			SIM CHV1 lock status
///
/// \param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_SIM_LockStatus
/// \sa SWI_NOTIFY_SimStatusExp
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetSimLock(SWI_STRUCT_SIM_LockStatus* pSim, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to change CHV1 or CHV2 codes.  
///
/// SIM API functions can not be called until a ::SWI_NOTIFY_SimStatusExp
/// notification is received.  This indicates that the SIM is ready to 
/// process user requests.
/// 
/// The CHV1 code can only be changed when enabled (using SwiSetSimLock). 
/// Emergency numbers cannot be used as CHV1 codes, or as the beginning of 
/// CHV1 codes.  PUK1 and PUK2 are not valid parameters, although the data 
/// structure includes them.
///
///	\param	[IN] pSim:		
///			SIM password information
///
///	\param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed.  The ::SWI_NOTIFY_SimStatusExp 
///			notification indicates the result of the operation. 
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_SIM_Password
/// \sa SWI_NOTIFY_SimStatusExp
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetSimPassword(const SWI_STRUCT_SIM_Password* pSim, 
									U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to enter the MEP code and disable the mechanism 
/// that restricts which SIMs can be used with the modem.  
/// 
/// SIM API functions can not be called until a ::SWI_NOTIFY_SimStatusExp
/// notification is received.  This indicates that the SIM is ready to 
/// process user requests.
///
/// Once this function is called do not call it again until the result from the
/// current request has been received in the next ::SWI_NOTIFY_SimStatusExp 
/// notification.  
///
/// The first time that this function is called, there is a 30 second delay 
/// before the ::SWI_NOTIFY_SimStatusExp notification responds. This delay is 
/// doubled with each attempt. (That is, the second time the function is
/// called, there is a one minute delay. The third time it is called, there 
/// is a two minute delay.) The delay is intended to discourage users from 
/// trying new codes until the SIM becomes blocked.
///			
/// \param	[IN] pMEP:
///			MEP unlocking code
///
/// \param	[IN] timeout:	
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed.  The ::SWI_NOTIFY_SimStatusExp 
///			notification indicates the result of the operation. 
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_MEP_Unlock
/// \sa SWI_NOTIFY_SimStatusExp
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetMEPUnlock(const SWI_STRUCT_MEP_Unlock* pMEP, 
								  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to retrieve the ICC ID of the SIM.
///	
/// This function should not be called until the ::SWI_NOTIFY_SimStatusExp
/// has been received indicating the SIM is ready. 
/// 
/// \param	[OUT] sIddId:		
///			ICC ID
///
/// \param	[IN] timeout:
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_IccId
/// \sa SWI_NOTIFY_SimStatusExp
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetIccId(SWI_STRUCT_IccId &sIddId, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to send a sixteen byte random number to the SIM.
/// The SIM will run its algorithm on the provided random number and it will
/// output a thirty two bit SIM response and eight byte ciphering key. 
/// 
/// SIM API functions can not be called until a ::SWI_NOTIFY_SimStatusExp
/// notification is received.  This indicates that the SIM is ready to 
/// process user requests.
///			
/// \param	[IN/OUT] pSimAuth:	 
///			SIM authentication information.  The size of the structure and
///			random number must be provided by the caller.  The response
///			will contain the 32-bit SIM response and ciphering key.
///
///	\param	[IN] timeout:
///			Response timeout value in milliseconds
///
/// \return	::SWI_RCODE_OK:
///			The request has been processed and values returned are valid.
///
///	\return	See ::SWI_RCODE for other error return codes.
///
/// \sa SWI_STRUCT_SimAuth
/// \sa SWI_NOTIFY_SimStatusExp
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetSimAuthentication(SWI_STRUCT_SimAuth *pSimAuth, 
										  U32 timeout);

/*@}*/ // End of SIM group

/**
 *	\defgroup GroupGsmSS Supplementary Services
 */
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// This function initiates a network password registration procedure for
/// either the call barring password or the general supplementary services
/// password.
///
/// A handle assigned to this registration request will be returned to the
/// caller by this function.
///		
/// \param  [IN/OUT] sSSPassReg: 
///         Specifies the kind of password being registered
///
/// \param  [IN] timeout: 
///         Response timeout value in milliseconds
///
/// \return ::SWI_RCODE_OK:
///         The request has been received by the device
///
/// \return See ::SWI_RCODE for other error return codes
///
///	\sa SWI_STRUCT_SS_PasswordReg
///	\sa SWI_NOTIFY_SSPasswordStatus
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiStartSSPassReg(SWI_STRUCT_SS_PasswordReg* sSSPassReg, 
									U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to enter a supplementary services password.  
///
/// It will be called in response to a received ::SWI_NOTIFY_SSPasswordStatus 
/// notification.  The notification will indicate what kind of password
/// needs to be entered.
///
/// The ::SWI_NOTIFY_SSRespPassword notification will indicate if the
/// supplementary services password process has been successful.
///
/// If an incorrect or invalid password has been entered, this will
/// be communicated in the ::SWI_NOTIFY_SSPasswordStatus notification. 
///		
/// \param  [IN] sSSPassStatus: 
///         Specifies the supplementary services request to be canceled
///
/// \param  [IN] timeout: 
///         Response timeout value in milliseconds
///
/// \return ::SWI_RCODE_OK:
///         The request has been received by the device
///
/// \return See ::SWI_RCODE for other error return codes
///
///	\sa SWI_STRUCT_SS_PasswordStatus
///	\sa SWI_NOTIFY_SSPasswordStatus
///	\sa SWI_NOTIFY_SSRespPassword
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetSSPassword(SWI_STRUCT_SS_PasswordStatus* sSSPassStatus,
								   U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to initiate supplementary services operations 
/// through one of five request types: erase, register, activate, 
/// deactivate and interrogate.
///
/// The requested operation will be assumed to affect all supplementary
/// services if no basic service group information is specified in the
/// request.
///
/// The device will return the supplementary service handle 
/// assigned to the request operation.  This handle allow the 
/// caller to map the network response received in one many 
/// supplementary service notification to this requested operation.
///
/// The handle can also be used to cancel the requested operation.
///		
/// \param  [IN/OUT] sSSRequest: 
///         Supplementary services request information
///
/// \param  [IN] timeout: 
///         Response timeout value in milliseconds
///
/// \return ::SWI_RCODE_OK:
///         The request has been received by the device
///
/// \return See ::SWI_RCODE for other error return codes
///
/// \sa SWI_STRUCT_SS_Request
///	\sa SWI_NOTIFY_SSRespOK
///	\sa SWI_NOTIFY_SSRespFwdInfo
///	\sa SWI_NOTIFY_SSRespCallBar
///	\sa SWI_NOTIFY_SSRespInfoData
///	\sa SWI_NOTIFY_SSRespStatus
///	\sa SWI_NOTIFY_SSRespFwdNum
///	\sa SWI_NOTIFY_SSRespBSList
///	\sa SWI_NOTIFY_SSRespFwdList
///	\sa SWI_NOTIFY_SSRespRaw
///	\sa SWI_NOTIFY_SSRespPassword
///	\sa SWI_NOTIFY_SSRespClir
///	\sa SWI_NOTIFY_SSRespError
///	\sa SWI_NOTIFY_SSRespReject
///	\sa SWI_NOTIFY_SSRespCancel
///	\sa SWI_NOTIFY_SSRespRelease
/// \sa SWI_NOTIFY_SSNotify
/// \sa SwiAbortRequest
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetSSRequest(SWI_STRUCT_SS_Request* sSSRequest, 
								  U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to cancel an outstanding supplementary service 
/// operation.
///		
/// \param  [IN] SWI_STRUCT_SS_Abort: 
///         Specifies the supplementary services request to be canceled
///
/// \param  [IN] timeout: 
///         Response timeout value in milliseconds
///
/// \return ::SWI_RCODE_OK:
///         The request has been received by the device
///
/// \return See ::SWI_RCODE for other error return codes
///
///	\sa SWI_STRUCT_SS_Abort
///	\sa SWI_NOTIFY_SSRespCancel
///	\sa SWI_NOTIFY_SSRespRelease
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiAbortRequest(SWI_STRUCT_SS_Abort* sSSAbort, U32 timeout);

/*@}*/	// End of supplementary services group 

#ifdef __cplusplus
} ///extern "C" {
#endif

#endif  ///_SWI_API_GSM_
