///////////////////////////////////////////////////////////////////////////////
//                                                                              
//  $Revision: 7 $                                                              
//                                                                              
//  Name       : SwiSms.h                                                       
//                                                                              
//  Purpose    : SWI SMS API interface                                          
//                                                                              
//  Copyright (c) 2008 Sierra Wireless, Inc.  All rights reserved               
//                                                                              
///////////////////////////////////////////////////////////////////////////////

#ifndef __SWISMSGSM_H__
#define __SWISMSGSM_H__

#ifndef SWI_API
#define SWI_API __declspec(dllimport)
#endif

#ifdef __cplusplus
extern "C" {
#endif

/** 
 *	\defgroup GroupGsmSms SMS
 */
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to determine the number of UNREAD and previously
/// READ mobile-terminated SMS messages currently stored on the SIM.
///
/// This function applies to all devices.
///
/// \param  [OUT] pSMS_Status:
///         Received SMS messages status
///
/// \param  [IN] timeout: 
///         Response timeout value in milliseconds
///
/// \return ::SWI_RCODE_OK:
///         The request has been received by the device
///
/// \return ::SWI_RCODE_REQUEST_TIMEOUT:
///         The  request has timed out
///
/// \return See SWI_RCODE for other error return codes
///
///	\sa SWI_STRUCT_GSM_SMS_Status
///	\sa See notification, SWI_NOTIFY_SmsStatus
///	\sa See notification, SWI_NOTIFY_SmsSimFull
///	\sa See sample code, Gsm_SMSInbox
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetSMSMessageStatus(
					SWI_STRUCT_GSM_SMS_Status *pSMS_Status, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to read a single mobile-terminated SMS 
/// message off the SIM.
///
/// Callers of this function must specify what kind of message will be
/// returned: UNREAD or previously READ.  The act of fetching an
/// UNREAD message from the SIM will convert its status to READ.
///
/// SMS messages are stored in a circular fashion on the SIM.  To read all
/// previously READ messages from the SIM, this function should be called
/// repeatedly until a duplicate SMS messages id is returned.  For UNREAD
/// messages, this function should be called until it fails.
///
/// This function applies to all devices.
///
/// \param  [IN/OUT] pSMS:
///         SMS message
///
/// \param  [IN] timeout: 
///         Response timeout value in milliseconds
///
/// \return ::SWI_RCODE_OK:
///         The request has been received by the device
///
/// \return ::SWI_RCODE_FAILED:
///         In the case when attempting to fetch an UNREAD message, this
///         this error indicates that currently there are no UNREAD messages.
///
/// \return ::SWI_RCODE_REQUEST_TIMEOUT:
///         The  request has timed out
///
/// \return See SWI_RCODE for other error return codes
///
///	\sa SWI_STRUCT_GSM_SMS_RetrieveSms
///	\sa See sample code, Gsm_SMSInbox
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiRetrieveSMSMessage(SWI_STRUCT_GSM_SMS_RetrieveSms *pSMS, 
										U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to delete a mobile-terminated SMS 
/// message from the SIM.  
///
/// Mobile-terminated SMS messages are NEVER automatically deleted 
/// from the SIM.  It is the responsibility of the host software
/// to explicitly remove individual messages.
///
/// There is not interface for removing stored mobile-originated
/// SMS messages.
///
/// This function is applies to all devices.
///         
/// \param  [OUT] msgID:
///         message identifier of the SMS message to delete
///
/// \param  [IN] timeout: 
///         Response timeout value in milliseconds
///
/// \return ::SWI_RCODE_OK:
///         The request has been received by the device
///
/// \return ::SWI_RCODE_REQUEST_TIMEOUT:
///         The  request has timed out
///
/// \return See ::SWI_RCODE for other error return codes
///
///	\sa See sample code, Gsm_SMSInbox
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiDeleteSMS(const U16 msgID, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function will fetch the SMS related parameters off the SIM.
///
/// This function applies to all devices.
///
/// \param  [OUT] pSmsParam:
///         SMS parameters
///
/// \param  [IN] timeout: 
///         Response timeout value in milliseconds
///
/// \return ::SWI_RCODE_OK:
///         The request has been received by the device
///
/// \return ::SWI_RCODE_REQUEST_TIMEOUT:
///         The  request has timed out
///
/// \return See SWI_RCODE for other error return codes
///
///	\sa SWI_STRUCT_SMS_Param
///	\sa See sample code, Gsm_SMSOutbox
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetSmsParam(SWI_STRUCT_SMS_Param *pSmsParam, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function will update the SMS related parameters on the SIM.
///
/// This function is applies to all devices.
///
/// \param  [IN] pSmsParam:
///         SMS parameters
///
/// \param  [IN] timeout: 
///         Response timeout value in milliseconds
///
/// \return ::SWI_RCODE_OK:
///         The request has been received by the device
///
/// \return ::SWI_RCODE_REQUEST_TIMEOUT: 
///         The  request has timed out
///
/// \return See ::SWI_RCODE for other error return codes
///
///	\sa SWI_STRUCT_SMS_Param
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetSmsParam(const SWI_STRUCT_SMS_Param *pSmsParam, 
								 U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to store a mobile-originated SMS message on the SIM.
/// It can be called repeatedly to store longer messages or multiple messages.
///
/// Once a mobile-terminated message or messages have been copied to the SIM
/// they can be sent by calling ::SwiSendSMS.  Sent messages will automatically
/// be deleted from the SIM.
///
/// This function will block until the SMS message or SMS message segment
/// has been copied to the SIM.  This can take up to 20 seconds.  For
/// most application that is a very long time to be blocked on an API.
/// To address this shortcoming this function has been replaced with
/// the non-blocking ::SwiStoreSMSMessageExp function.  
///
/// SwiStoreSMSMessageExp should be used instead of this function
///
/// This function applies to all devices.
///
/// \param  [IN] pStoreSMS:
///         SMS message to store
///
/// \param  [IN] timeout: 
///         Response timeout value in milliseconds
///
/// \return ::SWI_RCODE_OK:
///         The request has been received by the device
///
/// \return ::SWI_RCODE_REQUEST_TIMEOUT:
///         The  request has timed out
///
/// \return See ::SWI_RCODE for other error return codes
///
/// \sa This function is replaced by SwiStoreSMSMessageExp
///	\sa SwiSendSMS
///	\sa SWI_STRUCT_GSM_SMS_StoreSms
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiStoreSMSMessage(SWI_STRUCT_GSM_SMS_StoreSms *pStoreSMS, 
									 U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to send all stored mobile-originated
/// SMS message from the SIM.  Once these messages are sent they
/// will be deleted from the SIM.  The mobile-originated SMS messages 
/// were stored using ::SwiStoreSMSMessage.
///
/// This function will block until all the stored messages have been sent.
/// This can take up to 20 seconds.  For most application that is 
/// a very long time to be blocked on an API.  To address this 
/// shortcoming this function has been replaced with the non-blocking 
/// ::SwiSendSMSExp function. 
///
/// SwiSendSMSExp should be used instead of this function
///
/// This function applies to all devices.
///
/// \param  [IN] timeout: 
///         Response timeout value in milliseconds
///
/// \return ::SWI_RCODE_OK:
///         The request has been received by the device
///
/// \return ::SWI_RCODE_REQUEST_TIMEOUT:
///         The  request has timed out
///
/// \return See ::SWI_RCODE for other error return codes
///
/// \sa This function is replaced by SwiSendSMSExp
///	\sa SwiStoreSMSMessage
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSendSMS(U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to copy a mobile-originated SMS message to the SIM.
/// It can be called repeatedly to store longer messages or multiple messages.
///
/// Neither this function nor ::SwiSendSMSExp should not be called again 
/// until a ::SWI_NOTIFY_SmsStoreExp notification has been received 
/// indicating that the copy has been completed.
///
/// Once a mobile-terminated message or messages have been copied to the SIM
/// they can be sent by calling ::SwiSendSMSExp.  Sent messages will 
/// automatically be deleted from the SIM.
///
/// \param  [IN] pStoreSMS: 
///         SMS message to store
///
/// \param  [OUT] pcntSegments: 
///         Indicates the number of segments to be stored.  This is -1 
///			initially.
///
/// \param  [OUT] piSequence: 
///         Indicates the sequence number of the segment.  This is 0 initially.
///
/// \param  [IN] timeout: 
///         Response timeout value in milliseconds
///
/// \return ::SWI_RCODE_OK:
///         The request has been received by the device
///
/// \return ::SWI_RCODE_REQUEST_TIMEOUT:
///         The  request has timed out
///
/// \return See SWI_RCODE for other error return codes
///
///	\sa SwiSendSMSExp
/// \sa	SWI_NOTIFY_SmsStoreExp
///	\sa SWI_STRUCT_GSM_SMS_StoreSms
///	\sa See sample code, Gsm_SMSOutbox
///	\sa SwiStoreSMSMessage was replaced by this function
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiStoreSMSMessageExp(
					SWI_STRUCT_GSM_SMS_StoreSms *psStoreSMS, 
                    int *pcntSegments,
                    int *piSequence,
                    U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to send all stored mobile-originated
/// SMS message from the SIM.  Once these messages are sent they
/// will be deleted from the SIM.  The mobile-originated SMS messages 
/// were stored using ::SwiStoreSMSMessageExp.
///
/// Neither this function nor ::SwiStoreSMSMessageExp should not be called again 
/// until a ::SWI_NOTIFY_SmsSendExp notification has been received 
/// indicating that sending has been completed.
///
/// This function is used to send SMS messages already stored on the SIM.
/// The message sent was previously stored by ::SwiStoreSMSMessageExp.
///
/// This function applies to all devices.
///          
/// \param  [IN] timeout: 
///         Response timeout value in milliseconds
///
/// \return ::SWI_RCODE_OK:
///         The request has been received by the device
///
/// \return ::SWI_RCODE_REQUEST_TIMEOUT:
///         The  request has timed out
///
/// \return See SWI_RCODE for other error return codes
///
///	\sa SwiStoreSMSMessageExp
/// \sa	SWI_NOTIFY_SmsSendExp
///	\sa See sample code, Gsm_SMSOutbox
///	\sa SwiSendSMS was replaced by this function
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSendSMSExp(U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to determine whether SMS status reports are
///	currently enabled or disabled on the device.
///			
/// \param  [OUT] pSmsStsRptCfg: 
///         SMS status report configuration
///
/// \param  [IN] timeout: 
///         Response timeout value in milliseconds
///
/// \return ::SWI_RCODE_OK:
///         The request has been received by the device
///
/// \return ::SWI_RCODE_REQUEST_TIMEOUT:
///         The  request has timed out
///
/// \return See SWI_RCODE for other error return codes
///
///	\sa SWI_STRUCT_SmsStatusReportCfg
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetSmsStatusReportCfg(
					SWI_STRUCT_SmsStatusReportCfg* pSmsStsRptCfg, 
					U32 timeout);

///////////////////////////////////////////////////////////////////////////////
///
/// This function is used to configure the SMS status report settings
///		
/// \param  [IN] pSmsStsRptCfg: 
///         SMS status report configuration
///
/// \param  [IN] timeout: 
///         Response timeout value in milliseconds
///
/// \return ::SWI_RCODE_OK:
///         The request has been received by the device
///
/// \return ::SWI_RCODE_REQUEST_TIMEOUT:
///         The  request has timed out
///
/// \return See SWI_RCODE for other error return codes
///
///	\sa SWI_STRUCT_SmsStatusReportCfg
///
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetSmsStatusReportCfg(
					SWI_STRUCT_SmsStatusReportCfg* pSmsStsRptCfg, 
					U32 timeout);

/*@}*/	// End of GSM SMS

#ifdef __cplusplus
} //extern "C" {
#endif

#endif __SWISMSGSM_H__